Class: NgrokAPI::Models::EndpointConfiguration

Inherits:
Object
  • Object
show all
Defined in:
lib/ngrokapi/models/endpoint_configuration.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(client:, result:) ⇒ EndpointConfiguration

Returns a new instance of EndpointConfiguration.



29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
# File 'lib/ngrokapi/models/endpoint_configuration.rb', line 29

def initialize(client:, result:)
  @client = client
  @result = result
  @id = @result['id']
  @type = @result['type']
  @description = @result['description']
   = @result['metadata']
  @created_at = @result['created_at']
  @uri = @result['uri']
  @basic_auth = @result['basic_auth']
  @circuit_breaker = @result['circuit_breaker']
  @compression = @result['compression']
  @request_headers = @result['request_headers']
  @response_headers = @result['response_headers']
  @ip_policy = @result['ip_policy']
  @mutual_tls = @result['mutual_tls']
  @tls_termination = @result['tls_termination']
  @webhook_validation = @result['webhook_validation']
  @oauth = @result['oauth']
  @logging = @result['logging']
  @saml = @result['saml']
  @oidc = @result['oidc']
  @backend = @result['backend']
end

Instance Attribute Details

#backendObject (readonly)

Returns the value of attribute backend.



6
7
8
# File 'lib/ngrokapi/models/endpoint_configuration.rb', line 6

def backend
  @backend
end

#basic_authObject (readonly)

Returns the value of attribute basic_auth.



6
7
8
# File 'lib/ngrokapi/models/endpoint_configuration.rb', line 6

def basic_auth
  @basic_auth
end

#circuit_breakerObject (readonly)

Returns the value of attribute circuit_breaker.



6
7
8
# File 'lib/ngrokapi/models/endpoint_configuration.rb', line 6

def circuit_breaker
  @circuit_breaker
end

#clientObject (readonly)

Returns the value of attribute client.



6
7
8
# File 'lib/ngrokapi/models/endpoint_configuration.rb', line 6

def client
  @client
end

#compressionObject (readonly)

Returns the value of attribute compression.



6
7
8
# File 'lib/ngrokapi/models/endpoint_configuration.rb', line 6

def compression
  @compression
end

#created_atObject (readonly)

Returns the value of attribute created_at.



6
7
8
# File 'lib/ngrokapi/models/endpoint_configuration.rb', line 6

def created_at
  @created_at
end

#descriptionObject (readonly)

Returns the value of attribute description.



6
7
8
# File 'lib/ngrokapi/models/endpoint_configuration.rb', line 6

def description
  @description
end

#idObject (readonly)

Returns the value of attribute id.



6
7
8
# File 'lib/ngrokapi/models/endpoint_configuration.rb', line 6

def id
  @id
end

#ip_policyObject (readonly)

Returns the value of attribute ip_policy.



6
7
8
# File 'lib/ngrokapi/models/endpoint_configuration.rb', line 6

def ip_policy
  @ip_policy
end

#loggingObject (readonly)

Returns the value of attribute logging.



6
7
8
# File 'lib/ngrokapi/models/endpoint_configuration.rb', line 6

def logging
  @logging
end

#metadataObject (readonly)

Returns the value of attribute metadata.



6
7
8
# File 'lib/ngrokapi/models/endpoint_configuration.rb', line 6

def 
  
end

#mutual_tlsObject (readonly)

Returns the value of attribute mutual_tls.



6
7
8
# File 'lib/ngrokapi/models/endpoint_configuration.rb', line 6

def mutual_tls
  @mutual_tls
end

#oauthObject (readonly)

Returns the value of attribute oauth.



6
7
8
# File 'lib/ngrokapi/models/endpoint_configuration.rb', line 6

def oauth
  @oauth
end

#oidcObject (readonly)

Returns the value of attribute oidc.



6
7
8
# File 'lib/ngrokapi/models/endpoint_configuration.rb', line 6

def oidc
  @oidc
end

#request_headersObject (readonly)

Returns the value of attribute request_headers.



6
7
8
# File 'lib/ngrokapi/models/endpoint_configuration.rb', line 6

def request_headers
  @request_headers
end

#response_headersObject (readonly)

Returns the value of attribute response_headers.



6
7
8
# File 'lib/ngrokapi/models/endpoint_configuration.rb', line 6

def response_headers
  @response_headers
end

#resultObject (readonly)

Returns the value of attribute result.



6
7
8
# File 'lib/ngrokapi/models/endpoint_configuration.rb', line 6

def result
  @result
end

#samlObject (readonly)

Returns the value of attribute saml.



6
7
8
# File 'lib/ngrokapi/models/endpoint_configuration.rb', line 6

def saml
  @saml
end

#tls_terminationObject (readonly)

Returns the value of attribute tls_termination.



6
7
8
# File 'lib/ngrokapi/models/endpoint_configuration.rb', line 6

def tls_termination
  @tls_termination
end

#typeObject (readonly)

Returns the value of attribute type.



6
7
8
# File 'lib/ngrokapi/models/endpoint_configuration.rb', line 6

def type
  @type
end

#uriObject (readonly)

Returns the value of attribute uri.



6
7
8
# File 'lib/ngrokapi/models/endpoint_configuration.rb', line 6

def uri
  @uri
end

#webhook_validationObject (readonly)

Returns the value of attribute webhook_validation.



6
7
8
# File 'lib/ngrokapi/models/endpoint_configuration.rb', line 6

def webhook_validation
  @webhook_validation
end

Instance Method Details

#==(other) ⇒ Object



54
55
56
# File 'lib/ngrokapi/models/endpoint_configuration.rb', line 54

def ==(other)
  @result == other.result
end

#deleteObject

Delete an endpoint configuration. This operation will fail if the endpoint configuration is still referenced by any reserved domain or reserved address.

ngrok.com/docs/api#api-endpoint-configurations-delete



67
68
69
70
71
# File 'lib/ngrokapi/models/endpoint_configuration.rb', line 67

def delete
  @client.delete(
    id: @id
  )
end

#to_sObject



58
59
60
# File 'lib/ngrokapi/models/endpoint_configuration.rb', line 58

def to_s
  @result.to_s
end

#update(description: nil, metadata: nil, circuit_breaker: nil, compression: nil, request_headers: nil, response_headers: nil, ip_policy: nil, mutual_tls: nil, tls_termination: nil, webhook_validation: nil, oauth: nil, logging: nil, saml: nil, oidc: nil) ⇒ Object

Updates an endpoint configuration. If a module is not specified in the update, it will not be modified. However, each module configuration that is specified will completely replace the existing value. There is no way to delete an existing module via this API, instead use the delete module API.

ngrok.com/docs/api#api-endpoint-configurations-update



80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
# File 'lib/ngrokapi/models/endpoint_configuration.rb', line 80

def update(
  description: nil,
  metadata: nil,
  circuit_breaker: nil,
  compression: nil,
  request_headers: nil,
  response_headers: nil,
  ip_policy: nil,
  mutual_tls: nil,
  tls_termination: nil,
  webhook_validation: nil,
  oauth: nil,
  logging: nil,
  saml: nil,
  oidc: nil
)
  @description = description if description
   =  if 
  @circuit_breaker = circuit_breaker if circuit_breaker
  @compression = compression if compression
  @request_headers = request_headers if request_headers
  @response_headers = response_headers if response_headers
  @ip_policy = ip_policy if ip_policy
  @mutual_tls = mutual_tls if mutual_tls
  @tls_termination = tls_termination if tls_termination
  @webhook_validation = webhook_validation if webhook_validation
  @oauth = oauth if oauth
  @logging = logging if logging
  @saml = saml if saml
  @oidc = oidc if oidc
  @client.update(
    id: @id,
    description: description,
    metadata: ,
    circuit_breaker: circuit_breaker,
    compression: compression,
    request_headers: request_headers,
    response_headers: response_headers,
    ip_policy: ip_policy,
    mutual_tls: mutual_tls,
    tls_termination: tls_termination,
    webhook_validation: webhook_validation,
    oauth: oauth,
    logging: logging,
    saml: saml,
    oidc: oidc
  )
end