Class: NgrokAPI::Models::TLSEdge
- Inherits:
-
Object
- Object
- NgrokAPI::Models::TLSEdge
- Defined in:
- lib/ngrokapi/models/tls_edge.rb
Instance Attribute Summary collapse
-
#backend ⇒ Object
readonly
Returns the value of attribute backend.
-
#client ⇒ Object
readonly
Returns the value of attribute client.
-
#created_at ⇒ Object
readonly
Returns the value of attribute created_at.
-
#description ⇒ Object
readonly
Returns the value of attribute description.
-
#hostports ⇒ Object
readonly
Returns the value of attribute hostports.
-
#id ⇒ Object
readonly
Returns the value of attribute id.
-
#ip_restriction ⇒ Object
readonly
Returns the value of attribute ip_restriction.
-
#metadata ⇒ Object
readonly
Returns the value of attribute metadata.
-
#mutual_tls ⇒ Object
readonly
Returns the value of attribute mutual_tls.
-
#result ⇒ Object
readonly
Returns the value of attribute result.
-
#tls_termination ⇒ Object
readonly
Returns the value of attribute tls_termination.
-
#uri ⇒ Object
readonly
Returns the value of attribute uri.
Instance Method Summary collapse
- #==(other) ⇒ Object
-
#delete ⇒ Object
Delete a TLS Edge by ID.
-
#initialize(client:, result:) ⇒ TLSEdge
constructor
A new instance of TLSEdge.
- #to_s ⇒ Object
-
#update(description: nil, metadata: nil, hostports: nil, backend: nil, ip_restriction: nil, mutual_tls: nil, tls_termination: nil) ⇒ Object
Updates a TLS Edge by ID.
Constructor Details
#initialize(client:, result:) ⇒ TLSEdge
Returns a new instance of TLSEdge.
19 20 21 22 23 24 25 26 27 28 29 30 31 32 |
# File 'lib/ngrokapi/models/tls_edge.rb', line 19 def initialize(client:, result:) @client = client @result = result @id = @result['id'] @description = @result['description'] @metadata = @result['metadata'] @created_at = @result['created_at'] @uri = @result['uri'] @hostports = @result['hostports'] @backend = @result['backend'] @ip_restriction = @result['ip_restriction'] @mutual_tls = @result['mutual_tls'] @tls_termination = @result['tls_termination'] end |
Instance Attribute Details
#backend ⇒ Object (readonly)
Returns the value of attribute backend.
6 7 8 |
# File 'lib/ngrokapi/models/tls_edge.rb', line 6 def backend @backend end |
#client ⇒ Object (readonly)
Returns the value of attribute client.
6 7 8 |
# File 'lib/ngrokapi/models/tls_edge.rb', line 6 def client @client end |
#created_at ⇒ Object (readonly)
Returns the value of attribute created_at.
6 7 8 |
# File 'lib/ngrokapi/models/tls_edge.rb', line 6 def created_at @created_at end |
#description ⇒ Object (readonly)
Returns the value of attribute description.
6 7 8 |
# File 'lib/ngrokapi/models/tls_edge.rb', line 6 def description @description end |
#hostports ⇒ Object (readonly)
Returns the value of attribute hostports.
6 7 8 |
# File 'lib/ngrokapi/models/tls_edge.rb', line 6 def hostports @hostports end |
#id ⇒ Object (readonly)
Returns the value of attribute id.
6 7 8 |
# File 'lib/ngrokapi/models/tls_edge.rb', line 6 def id @id end |
#ip_restriction ⇒ Object (readonly)
Returns the value of attribute ip_restriction.
6 7 8 |
# File 'lib/ngrokapi/models/tls_edge.rb', line 6 def ip_restriction @ip_restriction end |
#metadata ⇒ Object (readonly)
Returns the value of attribute metadata.
6 7 8 |
# File 'lib/ngrokapi/models/tls_edge.rb', line 6 def @metadata end |
#mutual_tls ⇒ Object (readonly)
Returns the value of attribute mutual_tls.
6 7 8 |
# File 'lib/ngrokapi/models/tls_edge.rb', line 6 def mutual_tls @mutual_tls end |
#result ⇒ Object (readonly)
Returns the value of attribute result.
6 7 8 |
# File 'lib/ngrokapi/models/tls_edge.rb', line 6 def result @result end |
#tls_termination ⇒ Object (readonly)
Returns the value of attribute tls_termination.
6 7 8 |
# File 'lib/ngrokapi/models/tls_edge.rb', line 6 def tls_termination @tls_termination end |
#uri ⇒ Object (readonly)
Returns the value of attribute uri.
6 7 8 |
# File 'lib/ngrokapi/models/tls_edge.rb', line 6 def uri @uri end |
Instance Method Details
#==(other) ⇒ Object
34 35 36 |
# File 'lib/ngrokapi/models/tls_edge.rb', line 34 def ==(other) @result == other.result end |
#delete ⇒ Object
Delete a TLS Edge by ID
81 82 83 84 85 |
# File 'lib/ngrokapi/models/tls_edge.rb', line 81 def delete @client.delete( id: @id ) end |
#to_s ⇒ Object
38 39 40 |
# File 'lib/ngrokapi/models/tls_edge.rb', line 38 def to_s @result.to_s end |
#update(description: nil, metadata: nil, hostports: nil, backend: nil, ip_restriction: nil, mutual_tls: nil, tls_termination: nil) ⇒ Object
Updates a TLS Edge by ID. If a module is not specified in the update, it will not be modified. However, each module configuration that is specified will completely replace the existing value. There is no way to delete an existing module via this API, instead use the delete module API.
49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/ngrokapi/models/tls_edge.rb', line 49 def update( description: nil, metadata: nil, hostports: nil, backend: nil, ip_restriction: nil, mutual_tls: nil, tls_termination: nil ) @description = description if description @metadata = if @hostports = hostports if hostports @backend = backend if backend @ip_restriction = ip_restriction if ip_restriction @mutual_tls = mutual_tls if mutual_tls @tls_termination = tls_termination if tls_termination @client.update( id: @id, description: description, metadata: , hostports: hostports, backend: backend, ip_restriction: ip_restriction, mutual_tls: mutual_tls, tls_termination: tls_termination ) end |