Class: NgrokAPI::Services::APIKeysClient

Inherits:
Object
  • Object
show all
Defined in:
lib/ngrokapi/services/api_keys_client.rb

Overview

API Keys are used to authenticate to the ngrok API. You may use the API itself to provision and manage API Keys but you'll need to provision your first API key from the API Keys page on your ngrok.com dashboard.

https://ngrok.com/docs/api#api-api-keys

Constant Summary collapse

PATH =

The API path for the requests

'/api_keys'
LIST_PROPERTY =

The List Property from the resulting API for list calls

'keys'

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(client:) ⇒ APIKeysClient



21
22
23
# File 'lib/ngrokapi/services/api_keys_client.rb', line 21

def initialize(client:)
  @client = client
end

Instance Attribute Details

#clientObject (readonly)

Returns the value of attribute client.



19
20
21
# File 'lib/ngrokapi/services/api_keys_client.rb', line 19

def client
  @client
end

Instance Method Details

#create(description: "", metadata: "") ⇒ NgrokAPI::Models::APIKey

Create a new API key. The generated API key can be used to authenticate to the ngrok API.

https://ngrok.com/docs/api#api-api-keys-create



34
35
36
37
38
39
40
41
42
43
# File 'lib/ngrokapi/services/api_keys_client.rb', line 34

def create(description: "", metadata: "")
  path = '/api_keys'
  replacements = {
  }
  data = {}
  data[:description] = description if description
  data[:metadata] =  if 
  result = @client.post(path % replacements, data: data)
  NgrokAPI::Models::APIKey.new(client: self, attrs: result)
end

#create!(description: "", metadata: "") ⇒ NgrokAPI::Models::APIKey

Create a new API key. The generated API key can be used to authenticate to the ngrok API. Throws an exception if API error.

https://ngrok.com/docs/api#api-api-keys-create



55
56
57
58
59
60
61
62
63
64
# File 'lib/ngrokapi/services/api_keys_client.rb', line 55

def create!(description: "", metadata: "")
  path = '/api_keys'
  replacements = {
  }
  data = {}
  data[:description] = description if description
  data[:metadata] =  if 
  result = @client.post(path % replacements, data: data, danger: true)
  NgrokAPI::Models::APIKey.new(client: self, attrs: result)
end

#delete(id: "") ⇒ NgrokAPI::Models::Empty



73
74
75
76
77
78
79
# File 'lib/ngrokapi/services/api_keys_client.rb', line 73

def delete(id: "")
  path = '/api_keys/%{id}'
  replacements = {
    id: id,
  }
  @client.delete(path % replacements)
end

#delete!(id: "") ⇒ NgrokAPI::Models::Empty

Delete an API key by ID Throws an exception if API error.

https://ngrok.com/docs/api#api-api-keys-delete



89
90
91
92
93
94
95
# File 'lib/ngrokapi/services/api_keys_client.rb', line 89

def delete!(id: "")
  path = '/api_keys/%{id}'
  replacements = {
    id: id,
  }
  @client.delete(path % replacements, danger: true)
end

#get(id: "") ⇒ NgrokAPI::Models::APIKey

Get the details of an API key by ID.

https://ngrok.com/docs/api#api-api-keys-get



104
105
106
107
108
109
110
111
112
# File 'lib/ngrokapi/services/api_keys_client.rb', line 104

def get(id: "")
  path = '/api_keys/%{id}'
  replacements = {
    id: id,
  }
  data = {}
  result = @client.get(path % replacements, data: data)
  NgrokAPI::Models::APIKey.new(client: self, attrs: result)
end

#get!(id: "") ⇒ NgrokAPI::Models::APIKey

Get the details of an API key by ID. Throws an exception if API error.

https://ngrok.com/docs/api#api-api-keys-get



122
123
124
125
126
127
128
129
130
# File 'lib/ngrokapi/services/api_keys_client.rb', line 122

def get!(id: "")
  path = '/api_keys/%{id}'
  replacements = {
    id: id,
  }
  data = {}
  result = @client.get(path % replacements, data: data, danger: true)
  NgrokAPI::Models::APIKey.new(client: self, attrs: result)
end

#list(before_id: nil, limit: nil, url: nil) ⇒ NgrokAPI::Models::Listable

List all API keys owned by this account

https://ngrok.com/docs/api#api-api-keys-list



141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
# File 'lib/ngrokapi/services/api_keys_client.rb', line 141

def list(before_id: nil, limit: nil, url: nil)
  result = @client.list(
    before_id: before_id,
    limit: limit,
    url: url,
    path: PATH
  )

  NgrokAPI::Models::Listable.new(
    client: self,
    attrs: result,
    list_property: LIST_PROPERTY,
    klass: NgrokAPI::Models::APIKey
  )
end

#list!(before_id: nil, limit: nil, url: nil) ⇒ NgrokAPI::Models::Listable

List all API keys owned by this account Throws an exception if API error.

https://ngrok.com/docs/api#api-api-keys-list



167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
# File 'lib/ngrokapi/services/api_keys_client.rb', line 167

def list!(before_id: nil, limit: nil, url: nil)
  result = @client.list(
    before_id: before_id,
    limit: limit,
    danger: true,
    url: url,
    path: PATH
  )

  NgrokAPI::Models::Listable.new(
    client: self,
    attrs: result,
    list_property: LIST_PROPERTY,
    klass: NgrokAPI::Models::APIKey,
    danger: true
  )
end

#update(id: "", description: nil, metadata: nil) ⇒ NgrokAPI::Models::APIKey

Update attributes of an API key by ID.

https://ngrok.com/docs/api#api-api-keys-update



194
195
196
197
198
199
200
201
202
203
204
# File 'lib/ngrokapi/services/api_keys_client.rb', line 194

def update(id: "", description: nil, metadata: nil)
  path = '/api_keys/%{id}'
  replacements = {
    id: id,
  }
  data = {}
  data[:description] = description if description
  data[:metadata] =  if 
  result = @client.patch(path % replacements, data: data)
  NgrokAPI::Models::APIKey.new(client: self, attrs: result)
end

#update!(id: "", description: nil, metadata: nil) ⇒ NgrokAPI::Models::APIKey

Update attributes of an API key by ID. Throws an exception if API error.

https://ngrok.com/docs/api#api-api-keys-update



216
217
218
219
220
221
222
223
224
225
226
# File 'lib/ngrokapi/services/api_keys_client.rb', line 216

def update!(id: "", description: nil, metadata: nil)
  path = '/api_keys/%{id}'
  replacements = {
    id: id,
  }
  data = {}
  data[:description] = description if description
  data[:metadata] =  if 
  result = @client.patch(path % replacements, data: data, danger: true)
  NgrokAPI::Models::APIKey.new(client: self, attrs: result)
end