Class: NgrokAPI::Services::CredentialsClient

Inherits:
Object
  • Object
show all
Defined in:
lib/ngrokapi/services/credentials_client.rb

Overview

Tunnel Credentials are ngrok agent authtokens. They authorize the ngrok agent to connect the ngrok service as your account. They are installed with the ngrok config add-authtoken command or by specifying it in the ngrok.yml configuration file with the authtoken property.

https://ngrok.com/docs/api#api-credentials

Constant Summary collapse

PATH =

The API path for the requests

'/credentials'
LIST_PROPERTY =

The List Property from the resulting API for list calls

'credentials'

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(client:) ⇒ CredentialsClient



22
23
24
# File 'lib/ngrokapi/services/credentials_client.rb', line 22

def initialize(client:)
  @client = client
end

Instance Attribute Details

#clientObject (readonly)

Returns the value of attribute client.



20
21
22
# File 'lib/ngrokapi/services/credentials_client.rb', line 20

def client
  @client
end

Instance Method Details

#create(description: "", metadata: "", acl: [], owner_id: nil, owner_email: "", precomputed_token: nil, scim_user_id: "") ⇒ NgrokAPI::Models::Credential

Create a new tunnel authtoken credential. This authtoken credential can be used to start a new tunnel session. The response to this API call is the only time the generated token is available. If you need it for future use, you must save it securely yourself.

https://ngrok.com/docs/api#api-credentials-create



39
40
41
42
43
44
45
46
47
48
49
50
# File 'lib/ngrokapi/services/credentials_client.rb', line 39

def create(description: "", metadata: "", acl: [], owner_id: nil, owner_email: "", precomputed_token: nil, scim_user_id: "")
  path = '/credentials'
  replacements = {
  }
  data = {}
  data[:description] = description if description
  data[:metadata] =  if 
  data[:acl] = acl if acl
  data[:owner_id] = owner_id if owner_id
  result = @client.post(path % replacements, data: data)
  NgrokAPI::Models::Credential.new(client: self, attrs: result)
end

#create!(description: "", metadata: "", acl: [], owner_id: nil, owner_email: "", precomputed_token: nil, scim_user_id: "") ⇒ NgrokAPI::Models::Credential

Create a new tunnel authtoken credential. This authtoken credential can be used to start a new tunnel session. The response to this API call is the only time the generated token is available. If you need it for future use, you must save it securely yourself. Throws an exception if API error.

https://ngrok.com/docs/api#api-credentials-create



66
67
68
69
70
71
72
73
74
75
76
77
# File 'lib/ngrokapi/services/credentials_client.rb', line 66

def create!(description: "", metadata: "", acl: [], owner_id: nil, owner_email: "", precomputed_token: nil, scim_user_id: "")
  path = '/credentials'
  replacements = {
  }
  data = {}
  data[:description] = description if description
  data[:metadata] =  if 
  data[:acl] = acl if acl
  data[:owner_id] = owner_id if owner_id
  result = @client.post(path % replacements, data: data, danger: true)
  NgrokAPI::Models::Credential.new(client: self, attrs: result)
end

#delete(id: "") ⇒ NgrokAPI::Models::Empty

Delete a tunnel authtoken credential by ID

https://ngrok.com/docs/api#api-credentials-delete



86
87
88
89
90
91
92
# File 'lib/ngrokapi/services/credentials_client.rb', line 86

def delete(id: "")
  path = '/credentials/%{id}'
  replacements = {
    id: id,
  }
  @client.delete(path % replacements)
end

#delete!(id: "") ⇒ NgrokAPI::Models::Empty

Delete a tunnel authtoken credential by ID Throws an exception if API error.

https://ngrok.com/docs/api#api-credentials-delete



102
103
104
105
106
107
108
# File 'lib/ngrokapi/services/credentials_client.rb', line 102

def delete!(id: "")
  path = '/credentials/%{id}'
  replacements = {
    id: id,
  }
  @client.delete(path % replacements, danger: true)
end

#get(id: "") ⇒ NgrokAPI::Models::Credential

Get detailed information about a tunnel authtoken credential

https://ngrok.com/docs/api#api-credentials-get



117
118
119
120
121
122
123
124
125
# File 'lib/ngrokapi/services/credentials_client.rb', line 117

def get(id: "")
  path = '/credentials/%{id}'
  replacements = {
    id: id,
  }
  data = {}
  result = @client.get(path % replacements, data: data)
  NgrokAPI::Models::Credential.new(client: self, attrs: result)
end

#get!(id: "") ⇒ NgrokAPI::Models::Credential

Get detailed information about a tunnel authtoken credential Throws an exception if API error.

https://ngrok.com/docs/api#api-credentials-get



135
136
137
138
139
140
141
142
143
# File 'lib/ngrokapi/services/credentials_client.rb', line 135

def get!(id: "")
  path = '/credentials/%{id}'
  replacements = {
    id: id,
  }
  data = {}
  result = @client.get(path % replacements, data: data, danger: true)
  NgrokAPI::Models::Credential.new(client: self, attrs: result)
end

#list(before_id: nil, limit: nil, filter: nil, url: nil) ⇒ NgrokAPI::Models::Listable

List all tunnel authtoken credentials on this account

https://ngrok.com/docs/api#api-credentials-list



155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
# File 'lib/ngrokapi/services/credentials_client.rb', line 155

def list(
  before_id: nil,
  limit: nil,
  filter: nil,
  url: nil
)
  result = @client.list(
    before_id: before_id,
    limit: limit,
    filter: filter,
    url: url,
    path: PATH
  )

  NgrokAPI::Models::Listable.new(
    client: self,
    attrs: result,
    list_property: LIST_PROPERTY,
    klass: NgrokAPI::Models::Credential
  )
end

#list!(before_id: nil, limit: nil, filter: nil, url: nil) ⇒ NgrokAPI::Models::Listable

List all tunnel authtoken credentials on this account Throws an exception if API error.

https://ngrok.com/docs/api#api-credentials-list



188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
# File 'lib/ngrokapi/services/credentials_client.rb', line 188

def list!(
  before_id: nil,
  limit: nil,
  filter: nil,
  url: nil
)
  result = @client.list(
    before_id: before_id,
    limit: limit,
    filter: filter,
    danger: true,
    url: url,
    path: PATH
  )

  NgrokAPI::Models::Listable.new(
    client: self,
    attrs: result,
    list_property: LIST_PROPERTY,
    klass: NgrokAPI::Models::Credential,
    danger: true
  )
end

#update(id: "", description: nil, metadata: nil, acl: nil) ⇒ NgrokAPI::Models::Credential

Update attributes of an tunnel authtoken credential by ID

https://ngrok.com/docs/api#api-credentials-update



222
223
224
225
226
227
228
229
230
231
232
233
# File 'lib/ngrokapi/services/credentials_client.rb', line 222

def update(id: "", description: nil, metadata: nil, acl: nil)
  path = '/credentials/%{id}'
  replacements = {
    id: id,
  }
  data = {}
  data[:description] = description if description
  data[:metadata] =  if 
  data[:acl] = acl if acl
  result = @client.patch(path % replacements, data: data)
  NgrokAPI::Models::Credential.new(client: self, attrs: result)
end

#update!(id: "", description: nil, metadata: nil, acl: nil) ⇒ NgrokAPI::Models::Credential

Update attributes of an tunnel authtoken credential by ID Throws an exception if API error.

https://ngrok.com/docs/api#api-credentials-update



246
247
248
249
250
251
252
253
254
255
256
257
# File 'lib/ngrokapi/services/credentials_client.rb', line 246

def update!(id: "", description: nil, metadata: nil, acl: nil)
  path = '/credentials/%{id}'
  replacements = {
    id: id,
  }
  data = {}
  data[:description] = description if description
  data[:metadata] =  if 
  data[:acl] = acl if acl
  result = @client.patch(path % replacements, data: data, danger: true)
  NgrokAPI::Models::Credential.new(client: self, attrs: result)
end