Class: NgrokAPI::Services::EdgesTLSClient

Inherits:
Object
  • Object
show all
Defined in:
lib/ngrokapi/services/edges_tls_client.rb

Overview

Constant Summary collapse

PATH =

The API path for the requests

'/edges/tls'
LIST_PROPERTY =

The List Property from the resulting API for list calls

'tls_edges'

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(client:) ⇒ EdgesTLSClient



17
18
19
# File 'lib/ngrokapi/services/edges_tls_client.rb', line 17

def initialize(client:)
  @client = client
end

Instance Attribute Details

#clientObject (readonly)

Returns the value of attribute client.



15
16
17
# File 'lib/ngrokapi/services/edges_tls_client.rb', line 15

def client
  @client
end

Instance Method Details

#create(description: "", metadata: "", hostports: nil, backend: nil, ip_restriction: nil, mutual_tls: nil, tls_termination: nil, policy: nil, traffic_policy: nil) ⇒ NgrokAPI::Models::TLSEdge



35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
# File 'lib/ngrokapi/services/edges_tls_client.rb', line 35

def create(description: "", metadata: "", hostports: nil, backend: nil, ip_restriction: nil, mutual_tls: nil, tls_termination: nil, policy: nil, traffic_policy: nil)
  path = '/edges/tls'
  replacements = {
  }
  data = {}
  data[:description] = description if description
  data[:metadata] =  if 
  data[:hostports] = hostports if hostports
  data[:backend] = backend if backend
  data[:ip_restriction] = ip_restriction if ip_restriction
  data[:mutual_tls] = mutual_tls if mutual_tls
  data[:tls_termination] = tls_termination if tls_termination
  data[:traffic_policy] = traffic_policy if traffic_policy
  result = @client.post(path % replacements, data: data)
  NgrokAPI::Models::TLSEdge.new(client: self, attrs: result)
end

#create!(description: "", metadata: "", hostports: nil, backend: nil, ip_restriction: nil, mutual_tls: nil, tls_termination: nil, policy: nil, traffic_policy: nil) ⇒ NgrokAPI::Models::TLSEdge

Create a TLS Edge Throws an exception if API error.

https://ngrok.com/docs/api#api-edges-tls-create



67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
# File 'lib/ngrokapi/services/edges_tls_client.rb', line 67

def create!(description: "", metadata: "", hostports: nil, backend: nil, ip_restriction: nil, mutual_tls: nil, tls_termination: nil, policy: nil, traffic_policy: nil)
  path = '/edges/tls'
  replacements = {
  }
  data = {}
  data[:description] = description if description
  data[:metadata] =  if 
  data[:hostports] = hostports if hostports
  data[:backend] = backend if backend
  data[:ip_restriction] = ip_restriction if ip_restriction
  data[:mutual_tls] = mutual_tls if mutual_tls
  data[:tls_termination] = tls_termination if tls_termination
  data[:traffic_policy] = traffic_policy if traffic_policy
  result = @client.post(path % replacements, data: data, danger: true)
  NgrokAPI::Models::TLSEdge.new(client: self, attrs: result)
end

#delete(id: "") ⇒ NgrokAPI::Models::Empty



260
261
262
263
264
265
266
# File 'lib/ngrokapi/services/edges_tls_client.rb', line 260

def delete(id: "")
  path = '/edges/tls/%{id}'
  replacements = {
    id: id,
  }
  @client.delete(path % replacements)
end

#delete!(id: "") ⇒ NgrokAPI::Models::Empty

Delete a TLS Edge by ID Throws an exception if API error.

https://ngrok.com/docs/api#api-edges-tls-delete



276
277
278
279
280
281
282
# File 'lib/ngrokapi/services/edges_tls_client.rb', line 276

def delete!(id: "")
  path = '/edges/tls/%{id}'
  replacements = {
    id: id,
  }
  @client.delete(path % replacements, danger: true)
end

#get(id: "") ⇒ NgrokAPI::Models::TLSEdge



91
92
93
94
95
96
97
98
99
# File 'lib/ngrokapi/services/edges_tls_client.rb', line 91

def get(id: "")
  path = '/edges/tls/%{id}'
  replacements = {
    id: id,
  }
  data = {}
  result = @client.get(path % replacements, data: data)
  NgrokAPI::Models::TLSEdge.new(client: self, attrs: result)
end

#get!(id: "") ⇒ NgrokAPI::Models::TLSEdge

Get a TLS Edge by ID Throws an exception if API error.

https://ngrok.com/docs/api#api-edges-tls-get



109
110
111
112
113
114
115
116
117
# File 'lib/ngrokapi/services/edges_tls_client.rb', line 109

def get!(id: "")
  path = '/edges/tls/%{id}'
  replacements = {
    id: id,
  }
  data = {}
  result = @client.get(path % replacements, data: data, danger: true)
  NgrokAPI::Models::TLSEdge.new(client: self, attrs: result)
end

#list(before_id: nil, limit: nil, url: nil) ⇒ NgrokAPI::Models::Listable

Returns a list of all TLS Edges on this account

https://ngrok.com/docs/api#api-edges-tls-list



128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
# File 'lib/ngrokapi/services/edges_tls_client.rb', line 128

def list(
  before_id: nil,
  limit: nil,
  url: nil
)
  result = @client.list(
    before_id: before_id,
    limit: limit,
    url: url,
    path: PATH
  )

  NgrokAPI::Models::Listable.new(
    client: self,
    attrs: result,
    list_property: LIST_PROPERTY,
    klass: NgrokAPI::Models::TLSEdge
  )
end

#list!(before_id: nil, limit: nil, url: nil) ⇒ NgrokAPI::Models::Listable

Returns a list of all TLS Edges on this account Throws an exception if API error.

https://ngrok.com/docs/api#api-edges-tls-list



158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
# File 'lib/ngrokapi/services/edges_tls_client.rb', line 158

def list!(
  before_id: nil,
  limit: nil,
  url: nil
)
  result = @client.list(
    before_id: before_id,
    limit: limit,
    danger: true,
    url: url,
    path: PATH
  )

  NgrokAPI::Models::Listable.new(
    client: self,
    attrs: result,
    list_property: LIST_PROPERTY,
    klass: NgrokAPI::Models::TLSEdge,
    danger: true
  )
end

#update(id: "", description: nil, metadata: nil, hostports: nil, backend: nil, ip_restriction: nil, mutual_tls: nil, tls_termination: nil, policy: nil, traffic_policy: nil) ⇒ NgrokAPI::Models::TLSEdge

Updates a TLS Edge by ID. If a module is not specified in the update, it will not be modified. However, each module configuration that is specified will completely replace the existing value. There is no way to delete an existing module via this API, instead use the delete module API.

https://ngrok.com/docs/api#api-edges-tls-update



198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
# File 'lib/ngrokapi/services/edges_tls_client.rb', line 198

def update(id: "", description: nil, metadata: nil, hostports: nil, backend: nil, ip_restriction: nil, mutual_tls: nil, tls_termination: nil, policy: nil, traffic_policy: nil)
  path = '/edges/tls/%{id}'
  replacements = {
    id: id,
  }
  data = {}
  data[:description] = description if description
  data[:metadata] =  if 
  data[:hostports] = hostports if hostports
  data[:backend] = backend if backend
  data[:ip_restriction] = ip_restriction if ip_restriction
  data[:mutual_tls] = mutual_tls if mutual_tls
  data[:tls_termination] = tls_termination if tls_termination
  data[:traffic_policy] = traffic_policy if traffic_policy
  result = @client.patch(path % replacements, data: data)
  NgrokAPI::Models::TLSEdge.new(client: self, attrs: result)
end

#update!(id: "", description: nil, metadata: nil, hostports: nil, backend: nil, ip_restriction: nil, mutual_tls: nil, tls_termination: nil, policy: nil, traffic_policy: nil) ⇒ NgrokAPI::Models::TLSEdge

Updates a TLS Edge by ID. If a module is not specified in the update, it will not be modified. However, each module configuration that is specified will completely replace the existing value. There is no way to delete an existing module via this API, instead use the delete module API. Throws an exception if API error.

https://ngrok.com/docs/api#api-edges-tls-update



235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
# File 'lib/ngrokapi/services/edges_tls_client.rb', line 235

def update!(id: "", description: nil, metadata: nil, hostports: nil, backend: nil, ip_restriction: nil, mutual_tls: nil, tls_termination: nil, policy: nil, traffic_policy: nil)
  path = '/edges/tls/%{id}'
  replacements = {
    id: id,
  }
  data = {}
  data[:description] = description if description
  data[:metadata] =  if 
  data[:hostports] = hostports if hostports
  data[:backend] = backend if backend
  data[:ip_restriction] = ip_restriction if ip_restriction
  data[:mutual_tls] = mutual_tls if mutual_tls
  data[:tls_termination] = tls_termination if tls_termination
  data[:traffic_policy] = traffic_policy if traffic_policy
  result = @client.patch(path % replacements, data: data, danger: true)
  NgrokAPI::Models::TLSEdge.new(client: self, attrs: result)
end