Class: NgrokAPI::Services::FailoverBackendsClient

Inherits:
Object
  • Object
show all
Defined in:
lib/ngrokapi/services/failover_backends_client.rb

Overview

A Failover backend defines failover behavior within a list of referenced backends. Traffic is sent to the first backend in the list. If that backend is offline or no connection can be established, ngrok attempts to connect to the next backend in the list until one is successful.

https://ngrok.com/docs/api#api-failover-backends

Constant Summary collapse

PATH =

The API path for the requests

'/backends/failover'
LIST_PROPERTY =

The List Property from the resulting API for list calls

'backends'

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(client:) ⇒ FailoverBackendsClient



20
21
22
# File 'lib/ngrokapi/services/failover_backends_client.rb', line 20

def initialize(client:)
  @client = client
end

Instance Attribute Details

#clientObject (readonly)

Returns the value of attribute client.



18
19
20
# File 'lib/ngrokapi/services/failover_backends_client.rb', line 18

def client
  @client
end

Instance Method Details

#create(description: "", metadata: "", backends: []) ⇒ NgrokAPI::Models::FailoverBackend



33
34
35
36
37
38
39
40
41
42
43
# File 'lib/ngrokapi/services/failover_backends_client.rb', line 33

def create(description: "", metadata: "", backends: [])
  path = '/backends/failover'
  replacements = {
  }
  data = {}
  data[:description] = description if description
  data[:metadata] =  if 
  data[:backends] = backends if backends
  result = @client.post(path % replacements, data: data)
  NgrokAPI::Models::FailoverBackend.new(client: self, attrs: result)
end

#create!(description: "", metadata: "", backends: []) ⇒ NgrokAPI::Models::FailoverBackend

Create a new Failover backend Throws an exception if API error.

https://ngrok.com/docs/api#api-failover-backends-create



55
56
57
58
59
60
61
62
63
64
65
# File 'lib/ngrokapi/services/failover_backends_client.rb', line 55

def create!(description: "", metadata: "", backends: [])
  path = '/backends/failover'
  replacements = {
  }
  data = {}
  data[:description] = description if description
  data[:metadata] =  if 
  data[:backends] = backends if backends
  result = @client.post(path % replacements, data: data, danger: true)
  NgrokAPI::Models::FailoverBackend.new(client: self, attrs: result)
end

#delete(id: "") ⇒ NgrokAPI::Models::Empty



74
75
76
77
78
79
80
# File 'lib/ngrokapi/services/failover_backends_client.rb', line 74

def delete(id: "")
  path = '/backends/failover/%{id}'
  replacements = {
    id: id,
  }
  @client.delete(path % replacements)
end

#delete!(id: "") ⇒ NgrokAPI::Models::Empty

Delete a Failover backend by ID. Throws an exception if API error.

https://ngrok.com/docs/api#api-failover-backends-delete



90
91
92
93
94
95
96
# File 'lib/ngrokapi/services/failover_backends_client.rb', line 90

def delete!(id: "")
  path = '/backends/failover/%{id}'
  replacements = {
    id: id,
  }
  @client.delete(path % replacements, danger: true)
end

#get(id: "") ⇒ NgrokAPI::Models::FailoverBackend

Get detailed information about a Failover backend by ID

https://ngrok.com/docs/api#api-failover-backends-get



105
106
107
108
109
110
111
112
113
# File 'lib/ngrokapi/services/failover_backends_client.rb', line 105

def get(id: "")
  path = '/backends/failover/%{id}'
  replacements = {
    id: id,
  }
  data = {}
  result = @client.get(path % replacements, data: data)
  NgrokAPI::Models::FailoverBackend.new(client: self, attrs: result)
end

#get!(id: "") ⇒ NgrokAPI::Models::FailoverBackend

Get detailed information about a Failover backend by ID Throws an exception if API error.

https://ngrok.com/docs/api#api-failover-backends-get



123
124
125
126
127
128
129
130
131
# File 'lib/ngrokapi/services/failover_backends_client.rb', line 123

def get!(id: "")
  path = '/backends/failover/%{id}'
  replacements = {
    id: id,
  }
  data = {}
  result = @client.get(path % replacements, data: data, danger: true)
  NgrokAPI::Models::FailoverBackend.new(client: self, attrs: result)
end

#list(before_id: nil, limit: nil, url: nil) ⇒ NgrokAPI::Models::Listable

List all Failover backends on this account

https://ngrok.com/docs/api#api-failover-backends-list



142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
# File 'lib/ngrokapi/services/failover_backends_client.rb', line 142

def list(before_id: nil, limit: nil, url: nil)
  result = @client.list(
    before_id: before_id,
    limit: limit,
    url: url,
    path: PATH
  )

  NgrokAPI::Models::Listable.new(
    client: self,
    attrs: result,
    list_property: LIST_PROPERTY,
    klass: NgrokAPI::Models::FailoverBackend
  )
end

#list!(before_id: nil, limit: nil, url: nil) ⇒ NgrokAPI::Models::Listable

List all Failover backends on this account Throws an exception if API error.

https://ngrok.com/docs/api#api-failover-backends-list



168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
# File 'lib/ngrokapi/services/failover_backends_client.rb', line 168

def list!(before_id: nil, limit: nil, url: nil)
  result = @client.list(
    before_id: before_id,
    limit: limit,
    danger: true,
    url: url,
    path: PATH
  )

  NgrokAPI::Models::Listable.new(
    client: self,
    attrs: result,
    list_property: LIST_PROPERTY,
    klass: NgrokAPI::Models::FailoverBackend,
    danger: true
  )
end

#update(id: "", description: nil, metadata: nil, backends: []) ⇒ NgrokAPI::Models::FailoverBackend



196
197
198
199
200
201
202
203
204
205
206
207
# File 'lib/ngrokapi/services/failover_backends_client.rb', line 196

def update(id: "", description: nil, metadata: nil, backends: [])
  path = '/backends/failover/%{id}'
  replacements = {
    id: id,
  }
  data = {}
  data[:description] = description if description
  data[:metadata] =  if 
  data[:backends] = backends if backends
  result = @client.patch(path % replacements, data: data)
  NgrokAPI::Models::FailoverBackend.new(client: self, attrs: result)
end

#update!(id: "", description: nil, metadata: nil, backends: []) ⇒ NgrokAPI::Models::FailoverBackend

Update Failover backend by ID Throws an exception if API error.

https://ngrok.com/docs/api#api-failover-backends-update



220
221
222
223
224
225
226
227
228
229
230
231
# File 'lib/ngrokapi/services/failover_backends_client.rb', line 220

def update!(id: "", description: nil, metadata: nil, backends: [])
  path = '/backends/failover/%{id}'
  replacements = {
    id: id,
  }
  data = {}
  data[:description] = description if description
  data[:metadata] =  if 
  data[:backends] = backends if backends
  result = @client.patch(path % replacements, data: data, danger: true)
  NgrokAPI::Models::FailoverBackend.new(client: self, attrs: result)
end