Class: NgrokAPI::Services::IPRestrictionsClient

Inherits:
Object
  • Object
show all
Defined in:
lib/ngrokapi/services/ip_restrictions_client.rb

Overview

An IP restriction is a restriction placed on the CIDRs that are allowed to

initate traffic to a specific aspect of your ngrok account. An IP
restriction has a type which defines the ingress it applies to. IP
restrictions can be used to enforce the source IPs that can make API
requests, log in to the dashboard, start ngrok agents, and connect to your
public-facing endpoints.

ngrok.com/docs/api#api-ip-restrictions

Constant Summary collapse

PATH =

The API path for the requests

'/ip_restrictions'
LIST_PROPERTY =

The List Property from the resulting API for list calls

'ip_restrictions'

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(client:) ⇒ IPRestrictionsClient

Returns a new instance of IPRestrictionsClient.



22
23
24
# File 'lib/ngrokapi/services/ip_restrictions_client.rb', line 22

def initialize(client:)
  @client = client
end

Instance Attribute Details

#clientObject (readonly)

Returns the value of attribute client.



20
21
22
# File 'lib/ngrokapi/services/ip_restrictions_client.rb', line 20

def client
  @client
end

Instance Method Details

#create(description: "", metadata: "", enforced: False, type:, ip_policy_ids:) ⇒ NgrokAPI::Models::IPRestriction

Create a new IP restriction

ngrok.com/docs/api#api-ip-restrictions-create

Parameters:

  • description (string) (defaults to: "")

    human-readable description of this IP restriction. optional, max 255 bytes.

  • metadata (string) (defaults to: "")

    arbitrary user-defined machine-readable data of this IP restriction. optional, max 4096 bytes.

  • enforced (boolean) (defaults to: False)

    true if the IP restriction will be enforced. if false, only warnings will be issued

  • type (string)

    the type of IP restriction. this defines what traffic will be restricted with the attached policies. four values are currently supported: dashboard, api, agent, and endpoints

  • ip_policy_ids (List<string>)

    the set of IP policy identifiers that are used to enforce the restriction

Returns:



37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
# File 'lib/ngrokapi/services/ip_restrictions_client.rb', line 37

def create(
  description: "",
  metadata: "",
  enforced: False,
  type:,
  ip_policy_ids:
)
  path = '/ip_restrictions'
  replacements = {
  }
  data = {}
  data[:description] = description if description
  data[:metadata] =  if 
  data[:enforced] = enforced if enforced
  data[:type] = type if type
  data[:ip_policy_ids] = ip_policy_ids if ip_policy_ids
  result = @client.post(path % replacements, data: data)
  NgrokAPI::Models::IPRestriction.new(client: self, result: result)
end

#delete(id: "") ⇒ NgrokAPI::Models::Empty

Parameters:

  • id (string) (defaults to: "")

    a resource identifier

Returns:

  • (NgrokAPI::Models::Empty)

    result from the API request



64
65
66
67
68
69
70
71
72
# File 'lib/ngrokapi/services/ip_restrictions_client.rb', line 64

def delete(
  id: ""
)
  path = '/ip_restrictions/%{id}'
  replacements = {
    id: id,
  }
  @client.delete(path % replacements)
end

#delete!(id: "") ⇒ NgrokAPI::Models::Empty

Delete an IP restriction Throws an exception if API error.

ngrok.com/docs/api#api-ip-restrictions-delete

Parameters:

  • id (string) (defaults to: "")

    a resource identifier

Returns:

  • (NgrokAPI::Models::Empty)

    result from the API request



82
83
84
85
86
87
88
89
90
# File 'lib/ngrokapi/services/ip_restrictions_client.rb', line 82

def delete!(
  id: ""
)
  path = '/ip_restrictions/%{id}'
  replacements = {
    id: id,
  }
  @client.delete(path % replacements, danger: true)
end

#get(id: "") ⇒ NgrokAPI::Models::IPRestriction

Get detailed information about an IP restriction

ngrok.com/docs/api#api-ip-restrictions-get

Parameters:

  • id (string) (defaults to: "")

    a resource identifier

Returns:



99
100
101
102
103
104
105
106
107
108
109
# File 'lib/ngrokapi/services/ip_restrictions_client.rb', line 99

def get(
  id: ""
)
  path = '/ip_restrictions/%{id}'
  replacements = {
    id: id,
  }
  data = {}
  result = @client.get(path % replacements, data: data)
  NgrokAPI::Models::IPRestriction.new(client: self, result: result)
end

#get!(id: "") ⇒ NgrokAPI::Models::IPRestriction

Get detailed information about an IP restriction Throws an exception if API error.

ngrok.com/docs/api#api-ip-restrictions-get

Parameters:

  • id (string) (defaults to: "")

    a resource identifier

Returns:



119
120
121
122
123
124
125
126
127
128
129
# File 'lib/ngrokapi/services/ip_restrictions_client.rb', line 119

def get!(
  id: ""
)
  path = '/ip_restrictions/%{id}'
  replacements = {
    id: id,
  }
  data = {}
  result = @client.get(path % replacements, data: data, danger: true)
  NgrokAPI::Models::IPRestriction.new(client: self, result: result)
end

#list(before_id: nil, limit: nil, url: nil) ⇒ NgrokAPI::Models::Listable

List all IP restrictions on this account

ngrok.com/docs/api#api-ip-restrictions-list

Parameters:

  • before_id (string) (defaults to: nil)
  • limit (string) (defaults to: nil)
  • url (string) (defaults to: nil)

    optional and mutually exclusive from before_id and limit

Returns:



140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
# File 'lib/ngrokapi/services/ip_restrictions_client.rb', line 140

def list(
  before_id: nil,
  limit: nil,
  url: nil
)
  result = @client.list(
    before_id: before_id,
    limit: limit,
    url: url,
    path: PATH
  )
  NgrokAPI::Models::Listable.new(
    client: self,
    result: result,
    list_property: LIST_PROPERTY,
    klass: NgrokAPI::Models::IPRestriction
  )
end

#update(id: "", description: nil, metadata: nil, enforced: nil, ip_policy_ids: []) ⇒ NgrokAPI::Models::IPRestriction

Update attributes of an IP restriction by ID

ngrok.com/docs/api#api-ip-restrictions-update

Parameters:

  • id (string) (defaults to: "")
  • description (string) (defaults to: nil)

    human-readable description of this IP restriction. optional, max 255 bytes.

  • metadata (string) (defaults to: nil)

    arbitrary user-defined machine-readable data of this IP restriction. optional, max 4096 bytes.

  • enforced (boolean) (defaults to: nil)

    true if the IP restriction will be enforced. if false, only warnings will be issued

  • ip_policy_ids (List<string>) (defaults to: [])

    the set of IP policy identifiers that are used to enforce the restriction

Returns:



170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
# File 'lib/ngrokapi/services/ip_restrictions_client.rb', line 170

def update(
  id: "",
  description: nil,
  metadata: nil,
  enforced: nil,
  ip_policy_ids: []
)
  path = '/ip_restrictions/%{id}'
  replacements = {
    id: id,
  }
  data = {}
  data[:description] = description if description
  data[:metadata] =  if 
  data[:enforced] = enforced if enforced
  data[:ip_policy_ids] = ip_policy_ids if ip_policy_ids
  result = @client.patch(path % replacements, data: data)
  NgrokAPI::Models::IPRestriction.new(client: self, result: result)
end

#update!(id: "", description: nil, metadata: nil, enforced: nil, ip_policy_ids: []) ⇒ NgrokAPI::Models::IPRestriction

Update attributes of an IP restriction by ID Throws an exception if API error.

ngrok.com/docs/api#api-ip-restrictions-update

Parameters:

  • id (string) (defaults to: "")
  • description (string) (defaults to: nil)

    human-readable description of this IP restriction. optional, max 255 bytes.

  • metadata (string) (defaults to: nil)

    arbitrary user-defined machine-readable data of this IP restriction. optional, max 4096 bytes.

  • enforced (boolean) (defaults to: nil)

    true if the IP restriction will be enforced. if false, only warnings will be issued

  • ip_policy_ids (List<string>) (defaults to: [])

    the set of IP policy identifiers that are used to enforce the restriction

Returns:



202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
# File 'lib/ngrokapi/services/ip_restrictions_client.rb', line 202

def update!(
  id: "",
  description: nil,
  metadata: nil,
  enforced: nil,
  ip_policy_ids: []
)
  path = '/ip_restrictions/%{id}'
  replacements = {
    id: id,
  }
  data = {}
  data[:description] = description if description
  data[:metadata] =  if 
  data[:enforced] = enforced if enforced
  data[:ip_policy_ids] = ip_policy_ids if ip_policy_ids
  result = @client.patch(path % replacements, data: data, danger: true)
  NgrokAPI::Models::IPRestriction.new(client: self, result: result)
end