Class: NgrokAPI::Services::SSHCertificateAuthoritiesClient

Inherits:
Object
  • Object
show all
Defined in:
lib/ngrokapi/services/ssh_certificate_authorities_client.rb

Overview

An SSH Certificate Authority is a pair of an SSH Certificate and its private key that can be used to sign other SSH host and user certificates.

https://ngrok.com/docs/api#api-ssh-certificate-authorities

Constant Summary collapse

PATH =

The API path for the requests

'/ssh_certificate_authorities'
LIST_PROPERTY =

The List Property from the resulting API for list calls

'ssh_certificate_authorities'

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(client:) ⇒ SSHCertificateAuthoritiesClient



18
19
20
# File 'lib/ngrokapi/services/ssh_certificate_authorities_client.rb', line 18

def initialize(client:)
  @client = client
end

Instance Attribute Details

#clientObject (readonly)

Returns the value of attribute client.



16
17
18
# File 'lib/ngrokapi/services/ssh_certificate_authorities_client.rb', line 16

def client
  @client
end

Instance Method Details

#create(description: "", metadata: "", private_key_type: "", elliptic_curve: "", key_size: 0) ⇒ NgrokAPI::Models::SSHCertificateAuthority



33
34
35
36
37
38
39
40
41
42
43
44
45
# File 'lib/ngrokapi/services/ssh_certificate_authorities_client.rb', line 33

def create(description: "", metadata: "", private_key_type: "", elliptic_curve: "", key_size: 0)
  path = '/ssh_certificate_authorities'
  replacements = {
  }
  data = {}
  data[:description] = description if description
  data[:metadata] =  if 
  data[:private_key_type] = private_key_type if private_key_type
  data[:elliptic_curve] = elliptic_curve if elliptic_curve
  data[:key_size] = key_size if key_size
  result = @client.post(path % replacements, data: data)
  NgrokAPI::Models::SSHCertificateAuthority.new(client: self, result: result)
end

#delete(id: "") ⇒ NgrokAPI::Models::Empty



54
55
56
57
58
59
60
# File 'lib/ngrokapi/services/ssh_certificate_authorities_client.rb', line 54

def delete(id: "")
  path = '/ssh_certificate_authorities/%{id}'
  replacements = {
    id: id,
  }
  @client.delete(path % replacements)
end

#delete!(id: "") ⇒ NgrokAPI::Models::Empty

Delete an SSH Certificate Authority Throws an exception if API error.

https://ngrok.com/docs/api#api-ssh-certificate-authorities-delete



70
71
72
73
74
75
76
# File 'lib/ngrokapi/services/ssh_certificate_authorities_client.rb', line 70

def delete!(id: "")
  path = '/ssh_certificate_authorities/%{id}'
  replacements = {
    id: id,
  }
  @client.delete(path % replacements, danger: true)
end

#get(id: "") ⇒ NgrokAPI::Models::SSHCertificateAuthority

Get detailed information about an SSH Certficate Authority

https://ngrok.com/docs/api#api-ssh-certificate-authorities-get



85
86
87
88
89
90
91
92
93
# File 'lib/ngrokapi/services/ssh_certificate_authorities_client.rb', line 85

def get(id: "")
  path = '/ssh_certificate_authorities/%{id}'
  replacements = {
    id: id,
  }
  data = {}
  result = @client.get(path % replacements, data: data)
  NgrokAPI::Models::SSHCertificateAuthority.new(client: self, result: result)
end

#get!(id: "") ⇒ NgrokAPI::Models::SSHCertificateAuthority

Get detailed information about an SSH Certficate Authority Throws an exception if API error.

https://ngrok.com/docs/api#api-ssh-certificate-authorities-get



103
104
105
106
107
108
109
110
111
# File 'lib/ngrokapi/services/ssh_certificate_authorities_client.rb', line 103

def get!(id: "")
  path = '/ssh_certificate_authorities/%{id}'
  replacements = {
    id: id,
  }
  data = {}
  result = @client.get(path % replacements, data: data, danger: true)
  NgrokAPI::Models::SSHCertificateAuthority.new(client: self, result: result)
end

#list(before_id: nil, limit: nil, url: nil) ⇒ NgrokAPI::Models::Listable

List all SSH Certificate Authorities on this account

https://ngrok.com/docs/api#api-ssh-certificate-authorities-list



122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
# File 'lib/ngrokapi/services/ssh_certificate_authorities_client.rb', line 122

def list(before_id: nil, limit: nil,
         url: nil)
  result = @client.list(
    before_id: before_id,
    limit: limit,
    url: url,
    path: PATH
  )

  NgrokAPI::Models::Listable.new(
    client: self,
    result: result,
    list_property: LIST_PROPERTY,
    klass: NgrokAPI::Models::SSHCertificateAuthority
  )
end

#list!(before_id: nil, limit: nil, url: nil) ⇒ NgrokAPI::Models::Listable

List all SSH Certificate Authorities on this account Throws an exception if API error.

https://ngrok.com/docs/api#api-ssh-certificate-authorities-list



149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
# File 'lib/ngrokapi/services/ssh_certificate_authorities_client.rb', line 149

def list!(before_id: nil, limit: nil,
          url: nil)
  result = @client.list(
    before_id: before_id,
    limit: limit,
    danger: true,
    url: url,
    path: PATH
  )

  NgrokAPI::Models::Listable.new(
    client: self,
    result: result,
    list_property: LIST_PROPERTY,
    klass: NgrokAPI::Models::SSHCertificateAuthority,
    danger: true
  )
end

#update(id: "", description: nil, metadata: nil) ⇒ NgrokAPI::Models::SSHCertificateAuthority



177
178
179
180
181
182
183
184
185
186
187
# File 'lib/ngrokapi/services/ssh_certificate_authorities_client.rb', line 177

def update(id: "", description: nil, metadata: nil)
  path = '/ssh_certificate_authorities/%{id}'
  replacements = {
    id: id,
  }
  data = {}
  data[:description] = description if description
  data[:metadata] =  if 
  result = @client.patch(path % replacements, data: data)
  NgrokAPI::Models::SSHCertificateAuthority.new(client: self, result: result)
end

#update!(id: "", description: nil, metadata: nil) ⇒ NgrokAPI::Models::SSHCertificateAuthority

Update an SSH Certificate Authority Throws an exception if API error.

https://ngrok.com/docs/api#api-ssh-certificate-authorities-update



199
200
201
202
203
204
205
206
207
208
209
# File 'lib/ngrokapi/services/ssh_certificate_authorities_client.rb', line 199

def update!(id: "", description: nil, metadata: nil)
  path = '/ssh_certificate_authorities/%{id}'
  replacements = {
    id: id,
  }
  data = {}
  data[:description] = description if description
  data[:metadata] =  if 
  result = @client.patch(path % replacements, data: data, danger: true)
  NgrokAPI::Models::SSHCertificateAuthority.new(client: self, result: result)
end