Class: NgrokAPI::Services::SSHCredentialsClient

Inherits:
Object
  • Object
show all
Defined in:
lib/ngrokapi/services/ssh_credentials_client.rb

Overview

SSH Credentials are SSH public keys that can be used to start SSH tunnels

via the ngrok SSH tunnel gateway.

ngrok.com/docs/api#api-ssh-credentials

Constant Summary collapse

PATH =

The API path for the requests

'/ssh_credentials'
LIST_PROPERTY =

The List Property from the resulting API for list calls

'ssh_credentials'

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(client:) ⇒ SSHCredentialsClient

Returns a new instance of SSHCredentialsClient.



18
19
20
# File 'lib/ngrokapi/services/ssh_credentials_client.rb', line 18

def initialize(client:)
  @client = client
end

Instance Attribute Details

#clientObject (readonly)

Returns the value of attribute client.



16
17
18
# File 'lib/ngrokapi/services/ssh_credentials_client.rb', line 16

def client
  @client
end

Instance Method Details

#create(description: "", metadata: "", acl: [], public_key:) ⇒ NgrokAPI::Models::SSHCredential

Create a new ssh_credential from an uploaded public SSH key. This ssh credential can be used to start new tunnels via ngrok’s SSH gateway.

ngrok.com/docs/api#api-ssh-credentials-create

Parameters:

  • (defaults to: "")

    human-readable description of who or what will use the ssh credential to authenticate. Optional, max 255 bytes.

  • (defaults to: "")

    arbitrary user-defined machine-readable data of this ssh credential. Optional, max 4096 bytes.

  • (defaults to: [])

    optional list of ACL rules. If unspecified, the credential will have no restrictions. The only allowed ACL rule at this time is the bind rule. The bind rule allows the caller to restrict what domains and addresses the token is allowed to bind. For example, to allow the token to open a tunnel on example.ngrok.io your ACL would include the rule bind:example.ngrok.io. Bind rules may specify a leading wildcard to match multiple domains with a common suffix. For example, you may specify a rule of “bind:*.example.com“ which will allow x.example.com, y.example.com, “*.example.com“, etc. A rule of “‘*’“ is equivalent to no acl at all and will explicitly permit all actions.

  • the PEM-encoded public key of the SSH keypair that will be used to authenticate

Returns:

  • result from the API request



33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
# File 'lib/ngrokapi/services/ssh_credentials_client.rb', line 33

def create(
  description: "",
  metadata: "",
  acl: [],
  public_key:
)
  path = '/ssh_credentials'
  replacements = {
  }
  data = {}
  data[:description] = description if description
  data[:metadata] =  if 
  data[:acl] = acl if acl
  data[:public_key] = public_key if public_key
  result = @client.post(path % replacements, data: data)
  NgrokAPI::Models::SSHCredential.new(client: self, result: result)
end

#delete(id: "") ⇒ NgrokAPI::Models::Empty

Delete an ssh_credential by ID

ngrok.com/docs/api#api-ssh-credentials-delete

Parameters:

  • (defaults to: "")

    a resource identifier

Returns:

  • result from the API request



58
59
60
61
62
63
64
65
66
# File 'lib/ngrokapi/services/ssh_credentials_client.rb', line 58

def delete(
  id: ""
)
  path = '/ssh_credentials/%{id}'
  replacements = {
    id: id,
  }
  @client.delete(path % replacements)
end

#delete!(id: "") ⇒ NgrokAPI::Models::Empty

Delete an ssh_credential by ID Throws an exception if API error.

ngrok.com/docs/api#api-ssh-credentials-delete

Parameters:

  • (defaults to: "")

    a resource identifier

Returns:

  • result from the API request



76
77
78
79
80
81
82
83
84
# File 'lib/ngrokapi/services/ssh_credentials_client.rb', line 76

def delete!(
  id: ""
)
  path = '/ssh_credentials/%{id}'
  replacements = {
    id: id,
  }
  @client.delete(path % replacements, danger: true)
end

#get(id: "") ⇒ NgrokAPI::Models::SSHCredential

Get detailed information about an ssh_credential

ngrok.com/docs/api#api-ssh-credentials-get

Parameters:

  • (defaults to: "")

    a resource identifier

Returns:

  • result from the API request



93
94
95
96
97
98
99
100
101
102
103
# File 'lib/ngrokapi/services/ssh_credentials_client.rb', line 93

def get(
  id: ""
)
  path = '/ssh_credentials/%{id}'
  replacements = {
    id: id,
  }
  data = {}
  result = @client.get(path % replacements, data: data)
  NgrokAPI::Models::SSHCredential.new(client: self, result: result)
end

#get!(id: "") ⇒ NgrokAPI::Models::SSHCredential

Get detailed information about an ssh_credential Throws an exception if API error.

ngrok.com/docs/api#api-ssh-credentials-get

Parameters:

  • (defaults to: "")

    a resource identifier

Returns:

  • result from the API request



113
114
115
116
117
118
119
120
121
122
123
# File 'lib/ngrokapi/services/ssh_credentials_client.rb', line 113

def get!(
  id: ""
)
  path = '/ssh_credentials/%{id}'
  replacements = {
    id: id,
  }
  data = {}
  result = @client.get(path % replacements, data: data, danger: true)
  NgrokAPI::Models::SSHCredential.new(client: self, result: result)
end

#list(before_id: nil, limit: nil, url: nil) ⇒ NgrokAPI::Models::Listable

List all ssh credentials on this account

ngrok.com/docs/api#api-ssh-credentials-list

Parameters:

  • (defaults to: nil)
  • (defaults to: nil)
  • (defaults to: nil)

    optional and mutually exclusive from before_id and limit

Returns:

  • result from the API request



134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
# File 'lib/ngrokapi/services/ssh_credentials_client.rb', line 134

def list(
  before_id: nil,
  limit: nil,
  url: nil
)
  result = @client.list(
    before_id: before_id,
    limit: limit,
    url: url,
    path: PATH
  )
  NgrokAPI::Models::Listable.new(
    client: self,
    result: result,
    list_property: LIST_PROPERTY,
    klass: NgrokAPI::Models::SSHCredential
  )
end

#update(id: "", description: nil, metadata: nil, acl: nil) ⇒ NgrokAPI::Models::SSHCredential

Update attributes of an ssh_credential by ID

ngrok.com/docs/api#api-ssh-credentials-update

Parameters:

  • (defaults to: "")
  • (defaults to: nil)

    human-readable description of who or what will use the ssh credential to authenticate. Optional, max 255 bytes.

  • (defaults to: nil)

    arbitrary user-defined machine-readable data of this ssh credential. Optional, max 4096 bytes.

  • (defaults to: nil)

    optional list of ACL rules. If unspecified, the credential will have no restrictions. The only allowed ACL rule at this time is the bind rule. The bind rule allows the caller to restrict what domains and addresses the token is allowed to bind. For example, to allow the token to open a tunnel on example.ngrok.io your ACL would include the rule bind:example.ngrok.io. Bind rules may specify a leading wildcard to match multiple domains with a common suffix. For example, you may specify a rule of “bind:*.example.com“ which will allow x.example.com, y.example.com, “*.example.com“, etc. A rule of “‘*’“ is equivalent to no acl at all and will explicitly permit all actions.

Returns:

  • result from the API request



163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
# File 'lib/ngrokapi/services/ssh_credentials_client.rb', line 163

def update(
  id: "",
  description: nil,
  metadata: nil,
  acl: nil
)
  path = '/ssh_credentials/%{id}'
  replacements = {
    id: id,
  }
  data = {}
  data[:description] = description if description
  data[:metadata] =  if 
  data[:acl] = acl if acl
  result = @client.patch(path % replacements, data: data)
  NgrokAPI::Models::SSHCredential.new(client: self, result: result)
end

#update!(id: "", description: nil, metadata: nil, acl: nil) ⇒ NgrokAPI::Models::SSHCredential

Update attributes of an ssh_credential by ID Throws an exception if API error.

ngrok.com/docs/api#api-ssh-credentials-update

Parameters:

  • (defaults to: "")
  • (defaults to: nil)

    human-readable description of who or what will use the ssh credential to authenticate. Optional, max 255 bytes.

  • (defaults to: nil)

    arbitrary user-defined machine-readable data of this ssh credential. Optional, max 4096 bytes.

  • (defaults to: nil)

    optional list of ACL rules. If unspecified, the credential will have no restrictions. The only allowed ACL rule at this time is the bind rule. The bind rule allows the caller to restrict what domains and addresses the token is allowed to bind. For example, to allow the token to open a tunnel on example.ngrok.io your ACL would include the rule bind:example.ngrok.io. Bind rules may specify a leading wildcard to match multiple domains with a common suffix. For example, you may specify a rule of “bind:*.example.com“ which will allow x.example.com, y.example.com, “*.example.com“, etc. A rule of “‘*’“ is equivalent to no acl at all and will explicitly permit all actions.

Returns:

  • result from the API request



192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
# File 'lib/ngrokapi/services/ssh_credentials_client.rb', line 192

def update!(
  id: "",
  description: nil,
  metadata: nil,
  acl: nil
)
  path = '/ssh_credentials/%{id}'
  replacements = {
    id: id,
  }
  data = {}
  data[:description] = description if description
  data[:metadata] =  if 
  data[:acl] = acl if acl
  result = @client.patch(path % replacements, data: data, danger: true)
  NgrokAPI::Models::SSHCredential.new(client: self, result: result)
end