Class: NgrokAPI::Services::CredentialsClient

Inherits:
Object
  • Object
show all
Defined in:
lib/ngrokapi/services/credentials_client.rb

Overview

Tunnel Credentials are ngrok agent authtokens. They authorize the ngrok agent to connect the ngrok service as your account. They are installed with the ngrok authtoken command or by specifying it in the ngrok.yml configuration file with the authtoken property.

https://ngrok.com/docs/api#api-credentials

Constant Summary collapse

PATH =

The API path for the requests

'/credentials'
LIST_PROPERTY =

The List Property from the resulting API for list calls

'credentials'

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(client:) ⇒ CredentialsClient



20
21
22
# File 'lib/ngrokapi/services/credentials_client.rb', line 20

def initialize(client:)
  @client = client
end

Instance Attribute Details

#clientObject (readonly)

Returns the value of attribute client.



18
19
20
# File 'lib/ngrokapi/services/credentials_client.rb', line 18

def client
  @client
end

Instance Method Details

#create(description: "", metadata: "", acl: []) ⇒ NgrokAPI::Models::Credential

Create a new tunnel authtoken credential. This authtoken credential can be used to start a new tunnel session. The response to this API call is the only time the generated token is available. If you need it for future use, you must save it securely yourself.

https://ngrok.com/docs/api#api-credentials-create



36
37
38
39
40
41
42
43
44
45
46
# File 'lib/ngrokapi/services/credentials_client.rb', line 36

def create(description: "", metadata: "", acl: [])
  path = '/credentials'
  replacements = {
  }
  data = {}
  data[:description] = description if description
  data[:metadata] =  if 
  data[:acl] = acl if acl
  result = @client.post(path % replacements, data: data)
  NgrokAPI::Models::Credential.new(client: self, result: result)
end

#delete(id: "") ⇒ NgrokAPI::Models::Empty

Delete a tunnel authtoken credential by ID

https://ngrok.com/docs/api#api-credentials-delete



55
56
57
58
59
60
61
# File 'lib/ngrokapi/services/credentials_client.rb', line 55

def delete(id: "")
  path = '/credentials/%{id}'
  replacements = {
    id: id,
  }
  @client.delete(path % replacements)
end

#delete!(id: "") ⇒ NgrokAPI::Models::Empty

Delete a tunnel authtoken credential by ID Throws an exception if API error.

https://ngrok.com/docs/api#api-credentials-delete



71
72
73
74
75
76
77
# File 'lib/ngrokapi/services/credentials_client.rb', line 71

def delete!(id: "")
  path = '/credentials/%{id}'
  replacements = {
    id: id,
  }
  @client.delete(path % replacements, danger: true)
end

#get(id: "") ⇒ NgrokAPI::Models::Credential

Get detailed information about a tunnel authtoken credential

https://ngrok.com/docs/api#api-credentials-get



86
87
88
89
90
91
92
93
94
# File 'lib/ngrokapi/services/credentials_client.rb', line 86

def get(id: "")
  path = '/credentials/%{id}'
  replacements = {
    id: id,
  }
  data = {}
  result = @client.get(path % replacements, data: data)
  NgrokAPI::Models::Credential.new(client: self, result: result)
end

#get!(id: "") ⇒ NgrokAPI::Models::Credential

Get detailed information about a tunnel authtoken credential Throws an exception if API error.

https://ngrok.com/docs/api#api-credentials-get



104
105
106
107
108
109
110
111
112
# File 'lib/ngrokapi/services/credentials_client.rb', line 104

def get!(id: "")
  path = '/credentials/%{id}'
  replacements = {
    id: id,
  }
  data = {}
  result = @client.get(path % replacements, data: data, danger: true)
  NgrokAPI::Models::Credential.new(client: self, result: result)
end

#list(before_id: nil, limit: nil, url: nil) ⇒ NgrokAPI::Models::Listable

List all tunnel authtoken credentials on this account

https://ngrok.com/docs/api#api-credentials-list



123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
# File 'lib/ngrokapi/services/credentials_client.rb', line 123

def list(before_id: nil, limit: nil,
         url: nil)
  result = @client.list(
    before_id: before_id,
    limit: limit,
    url: url,
    path: PATH
  )

  NgrokAPI::Models::Listable.new(
    client: self,
    result: result,
    list_property: LIST_PROPERTY,
    klass: NgrokAPI::Models::Credential
  )
end

#list!(before_id: nil, limit: nil, url: nil) ⇒ NgrokAPI::Models::Listable

List all tunnel authtoken credentials on this account Throws an exception if API error.

https://ngrok.com/docs/api#api-credentials-list



150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
# File 'lib/ngrokapi/services/credentials_client.rb', line 150

def list!(before_id: nil, limit: nil,
          url: nil)
  result = @client.list(
    before_id: before_id,
    limit: limit,
    danger: true,
    url: url,
    path: PATH
  )

  NgrokAPI::Models::Listable.new(
    client: self,
    result: result,
    list_property: LIST_PROPERTY,
    klass: NgrokAPI::Models::Credential,
    danger: true
  )
end

#update(id: "", description: nil, metadata: nil, acl: nil) ⇒ NgrokAPI::Models::Credential

Update attributes of an tunnel authtoken credential by ID

https://ngrok.com/docs/api#api-credentials-update



179
180
181
182
183
184
185
186
187
188
189
190
# File 'lib/ngrokapi/services/credentials_client.rb', line 179

def update(id: "", description: nil, metadata: nil, acl: nil)
  path = '/credentials/%{id}'
  replacements = {
    id: id,
  }
  data = {}
  data[:description] = description if description
  data[:metadata] =  if 
  data[:acl] = acl if acl
  result = @client.patch(path % replacements, data: data)
  NgrokAPI::Models::Credential.new(client: self, result: result)
end

#update!(id: "", description: nil, metadata: nil, acl: nil) ⇒ NgrokAPI::Models::Credential

Update attributes of an tunnel authtoken credential by ID Throws an exception if API error.

https://ngrok.com/docs/api#api-credentials-update



203
204
205
206
207
208
209
210
211
212
213
214
# File 'lib/ngrokapi/services/credentials_client.rb', line 203

def update!(id: "", description: nil, metadata: nil, acl: nil)
  path = '/credentials/%{id}'
  replacements = {
    id: id,
  }
  data = {}
  data[:description] = description if description
  data[:metadata] =  if 
  data[:acl] = acl if acl
  result = @client.patch(path % replacements, data: data, danger: true)
  NgrokAPI::Models::Credential.new(client: self, result: result)
end