Class: NgrokAPI::Services::CredentialsClient

Inherits:
Object
  • Object
show all
Defined in:
lib/ngrokapi/services/credentials_client.rb

Overview

Tunnel Credentials are ngrok agent authtokens. They authorize the ngrok

agent to connect the ngrok service as your . They are installed with
the ngrok authtoken command or by specifying it in the ngrok.yml
configuration file with the authtoken property.

ngrok.com/docs/api#api-credentials

Constant Summary collapse

PATH =

The API path for the requests

'/credentials'
LIST_PROPERTY =

The List Property from the resulting API for list calls

'credentials'

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(client:) ⇒ CredentialsClient

Returns a new instance of CredentialsClient.



20
21
22
# File 'lib/ngrokapi/services/credentials_client.rb', line 20

def initialize(client:)
  @client = client
end

Instance Attribute Details

#clientObject (readonly)

Returns the value of attribute client.



18
19
20
# File 'lib/ngrokapi/services/credentials_client.rb', line 18

def client
  @client
end

Instance Method Details

#create(description: "", metadata: "", acl: []) ⇒ NgrokAPI::Models::Credential

Create a new tunnel authtoken credential. This authtoken credential can be used to start a new tunnel session. The response to this API call is the only time the generated token is available. If you need it for future use, you must save it securely yourself.

ngrok.com/docs/api#api-credentials-create

Parameters:

  • description (string) (defaults to: "")

    human-readable description of who or what will use the credential to authenticate. Optional, max 255 bytes.

  • metadata (string) (defaults to: "")

    arbitrary user-defined machine-readable data of this credential. Optional, max 4096 bytes.

  • acl (List<string>) (defaults to: [])

    optional list of ACL rules. If unspecified, the credential will have no restrictions. The only allowed ACL rule at this time is the bind rule. The bind rule allows the caller to restrict what domains and addresses the token is allowed to bind. For example, to allow the token to open a tunnel on example.ngrok.io your ACL would include the rule bind:example.ngrok.io. Bind rules may specify a leading wildcard to match multiple domains with a common suffix. For example, you may specify a rule of “bind:*.example.com“ which will allow x.example.com, y.example.com, “*.example.com“, etc. A rule of “‘*’“ is equivalent to no acl at all and will explicitly permit all actions.

Returns:



36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
# File 'lib/ngrokapi/services/credentials_client.rb', line 36

def create(
  description: "",
  metadata: "",
  acl: []
)
  path = '/credentials'
  replacements = {
  }
  data = {}
  data[:description] = description if description
  data[:metadata] =  if 
  data[:acl] = acl if acl
  result = @client.post(path % replacements, data: data)
  NgrokAPI::Models::Credential.new(client: self, result: result)
end

#delete(id: "") ⇒ NgrokAPI::Models::Empty

Delete a tunnel authtoken credential by ID

ngrok.com/docs/api#api-credentials-delete

Parameters:

  • id (string) (defaults to: "")

    a resource identifier

Returns:

  • (NgrokAPI::Models::Empty)

    result from the API request



59
60
61
62
63
64
65
66
67
# File 'lib/ngrokapi/services/credentials_client.rb', line 59

def delete(
  id: ""
)
  path = '/credentials/%{id}'
  replacements = {
    id: id,
  }
  @client.delete(path % replacements)
end

#delete!(id: "") ⇒ NgrokAPI::Models::Empty

Delete a tunnel authtoken credential by ID Throws an exception if API error.

ngrok.com/docs/api#api-credentials-delete

Parameters:

  • id (string) (defaults to: "")

    a resource identifier

Returns:

  • (NgrokAPI::Models::Empty)

    result from the API request



77
78
79
80
81
82
83
84
85
# File 'lib/ngrokapi/services/credentials_client.rb', line 77

def delete!(
  id: ""
)
  path = '/credentials/%{id}'
  replacements = {
    id: id,
  }
  @client.delete(path % replacements, danger: true)
end

#get(id: "") ⇒ NgrokAPI::Models::Credential

Get detailed information about a tunnel authtoken credential

ngrok.com/docs/api#api-credentials-get

Parameters:

  • id (string) (defaults to: "")

    a resource identifier

Returns:



94
95
96
97
98
99
100
101
102
103
104
# File 'lib/ngrokapi/services/credentials_client.rb', line 94

def get(
  id: ""
)
  path = '/credentials/%{id}'
  replacements = {
    id: id,
  }
  data = {}
  result = @client.get(path % replacements, data: data)
  NgrokAPI::Models::Credential.new(client: self, result: result)
end

#get!(id: "") ⇒ NgrokAPI::Models::Credential

Get detailed information about a tunnel authtoken credential Throws an exception if API error.

ngrok.com/docs/api#api-credentials-get

Parameters:

  • id (string) (defaults to: "")

    a resource identifier

Returns:



114
115
116
117
118
119
120
121
122
123
124
# File 'lib/ngrokapi/services/credentials_client.rb', line 114

def get!(
  id: ""
)
  path = '/credentials/%{id}'
  replacements = {
    id: id,
  }
  data = {}
  result = @client.get(path % replacements, data: data, danger: true)
  NgrokAPI::Models::Credential.new(client: self, result: result)
end

#list(before_id: nil, limit: nil, url: nil) ⇒ NgrokAPI::Models::Listable

List all tunnel authtoken credentials on this account

ngrok.com/docs/api#api-credentials-list

Parameters:

  • before_id (string) (defaults to: nil)
  • limit (string) (defaults to: nil)
  • url (string) (defaults to: nil)

    optional and mutually exclusive from before_id and limit

Returns:



135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
# File 'lib/ngrokapi/services/credentials_client.rb', line 135

def list(
  before_id: nil,
  limit: nil,
  url: nil
)
  result = @client.list(
    before_id: before_id,
    limit: limit,
    url: url,
    path: PATH
  )
  NgrokAPI::Models::Listable.new(
    client: self,
    result: result,
    list_property: LIST_PROPERTY,
    klass: NgrokAPI::Models::Credential
  )
end

#update(id: "", description: nil, metadata: nil, acl: nil) ⇒ NgrokAPI::Models::Credential

Update attributes of an tunnel authtoken credential by ID

ngrok.com/docs/api#api-credentials-update

Parameters:

  • id (string) (defaults to: "")
  • description (string) (defaults to: nil)

    human-readable description of who or what will use the credential to authenticate. Optional, max 255 bytes.

  • metadata (string) (defaults to: nil)

    arbitrary user-defined machine-readable data of this credential. Optional, max 4096 bytes.

  • acl (List<string>) (defaults to: nil)

    optional list of ACL rules. If unspecified, the credential will have no restrictions. The only allowed ACL rule at this time is the bind rule. The bind rule allows the caller to restrict what domains and addresses the token is allowed to bind. For example, to allow the token to open a tunnel on example.ngrok.io your ACL would include the rule bind:example.ngrok.io. Bind rules may specify a leading wildcard to match multiple domains with a common suffix. For example, you may specify a rule of “bind:*.example.com“ which will allow x.example.com, y.example.com, “*.example.com“, etc. A rule of “‘*’“ is equivalent to no acl at all and will explicitly permit all actions.

Returns:



164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
# File 'lib/ngrokapi/services/credentials_client.rb', line 164

def update(
  id: "",
  description: nil,
  metadata: nil,
  acl: nil
)
  path = '/credentials/%{id}'
  replacements = {
    id: id,
  }
  data = {}
  data[:description] = description if description
  data[:metadata] =  if 
  data[:acl] = acl if acl
  result = @client.patch(path % replacements, data: data)
  NgrokAPI::Models::Credential.new(client: self, result: result)
end

#update!(id: "", description: nil, metadata: nil, acl: nil) ⇒ NgrokAPI::Models::Credential

Update attributes of an tunnel authtoken credential by ID Throws an exception if API error.

ngrok.com/docs/api#api-credentials-update

Parameters:

  • id (string) (defaults to: "")
  • description (string) (defaults to: nil)

    human-readable description of who or what will use the credential to authenticate. Optional, max 255 bytes.

  • metadata (string) (defaults to: nil)

    arbitrary user-defined machine-readable data of this credential. Optional, max 4096 bytes.

  • acl (List<string>) (defaults to: nil)

    optional list of ACL rules. If unspecified, the credential will have no restrictions. The only allowed ACL rule at this time is the bind rule. The bind rule allows the caller to restrict what domains and addresses the token is allowed to bind. For example, to allow the token to open a tunnel on example.ngrok.io your ACL would include the rule bind:example.ngrok.io. Bind rules may specify a leading wildcard to match multiple domains with a common suffix. For example, you may specify a rule of “bind:*.example.com“ which will allow x.example.com, y.example.com, “*.example.com“, etc. A rule of “‘*’“ is equivalent to no acl at all and will explicitly permit all actions.

Returns:



193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
# File 'lib/ngrokapi/services/credentials_client.rb', line 193

def update!(
  id: "",
  description: nil,
  metadata: nil,
  acl: nil
)
  path = '/credentials/%{id}'
  replacements = {
    id: id,
  }
  data = {}
  data[:description] = description if description
  data[:metadata] =  if 
  data[:acl] = acl if acl
  result = @client.patch(path % replacements, data: data, danger: true)
  NgrokAPI::Models::Credential.new(client: self, result: result)
end