Class: NgrokAPI::Services::EventDestinationsClient

Inherits:
Object
  • Object
show all
Defined in:
lib/ngrokapi/services/event_destinations_client.rb

Overview

Constant Summary collapse

PATH =

The API path for the requests

'/event_destinations'
LIST_PROPERTY =

The List Property from the resulting API for list calls

'event_destinations'

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(client:) ⇒ EventDestinationsClient

Returns a new instance of EventDestinationsClient.



15
16
17
# File 'lib/ngrokapi/services/event_destinations_client.rb', line 15

def initialize(client:)
  @client = client
end

Instance Attribute Details

#clientObject (readonly)

Returns the value of attribute client.



13
14
15
# File 'lib/ngrokapi/services/event_destinations_client.rb', line 13

def client
  @client
end

Instance Method Details

#create(metadata: "", description: "", format: "", target: nil, verify_with_test_event: nil) ⇒ NgrokAPI::Models::EventDestination

Create a new Event Destination. It will not apply to anything until it is associated with an Event Stream, and that Event Stream is associated with an Endpoint Config.

https://ngrok.com/docs/api#api-event-destinations-create

Parameters:

  • metadata (string) (defaults to: "")

    Arbitrary user-defined machine-readable data of this Event Destination. Optional, max 4096 bytes.

  • description (string) (defaults to: "")

    Human-readable description of the Event Destination. Optional, max 255 bytes.

  • format (string) (defaults to: "")

    The output format you would like to serialize events into when sending to their target. Currently the only accepted value is JSON.

  • target (EventTarget) (defaults to: nil)

    An object that encapsulates where and how to send your events. An event destination must contain exactly one of the following objects, leaving the rest null: kinesis, firehose, cloudwatch_logs, or s3.

Returns:



31
32
33
34
35
36
37
38
39
40
41
42
# File 'lib/ngrokapi/services/event_destinations_client.rb', line 31

def create(metadata: "", description: "", format: "", target: nil, verify_with_test_event: nil)
  path = '/event_destinations'
  replacements = {
  }
  data = {}
  data[:metadata] =  if 
  data[:description] = description if description
  data[:format] = format if format
  data[:target] = target if target
  result = @client.post(path % replacements, data: data)
  NgrokAPI::Models::EventDestination.new(client: self, result: result)
end

#delete(id: "") ⇒ NgrokAPI::Models::Empty

Delete an Event Destination. If the Event Destination is still referenced by an Event Stream, this will throw an error until that Event Stream has removed that reference.

https://ngrok.com/docs/api#api-event-destinations-delete

Parameters:

  • id (string) (defaults to: "")

    a resource identifier

Returns:

  • (NgrokAPI::Models::Empty)

    result from the API request



53
54
55
56
57
58
59
# File 'lib/ngrokapi/services/event_destinations_client.rb', line 53

def delete(id: "")
  path = '/event_destinations/%{id}'
  replacements = {
    id: id,
  }
  @client.delete(path % replacements)
end

#delete!(id: "") ⇒ NgrokAPI::Models::Empty

Delete an Event Destination. If the Event Destination is still referenced by an Event Stream, this will throw an error until that Event Stream has removed that reference. Throws an exception if API error.

https://ngrok.com/docs/api#api-event-destinations-delete

Parameters:

  • id (string) (defaults to: "")

    a resource identifier

Returns:

  • (NgrokAPI::Models::Empty)

    result from the API request



71
72
73
74
75
76
77
# File 'lib/ngrokapi/services/event_destinations_client.rb', line 71

def delete!(id: "")
  path = '/event_destinations/%{id}'
  replacements = {
    id: id,
  }
  @client.delete(path % replacements, danger: true)
end

#get(id: "") ⇒ NgrokAPI::Models::EventDestination

Get detailed information about an Event Destination by ID.

https://ngrok.com/docs/api#api-event-destinations-get

Parameters:

  • id (string) (defaults to: "")

    a resource identifier

Returns:



86
87
88
89
90
91
92
93
94
# File 'lib/ngrokapi/services/event_destinations_client.rb', line 86

def get(id: "")
  path = '/event_destinations/%{id}'
  replacements = {
    id: id,
  }
  data = {}
  result = @client.get(path % replacements, data: data)
  NgrokAPI::Models::EventDestination.new(client: self, result: result)
end

#get!(id: "") ⇒ NgrokAPI::Models::EventDestination

Get detailed information about an Event Destination by ID. Throws an exception if API error.

https://ngrok.com/docs/api#api-event-destinations-get

Parameters:

  • id (string) (defaults to: "")

    a resource identifier

Returns:



104
105
106
107
108
109
110
111
112
# File 'lib/ngrokapi/services/event_destinations_client.rb', line 104

def get!(id: "")
  path = '/event_destinations/%{id}'
  replacements = {
    id: id,
  }
  data = {}
  result = @client.get(path % replacements, data: data, danger: true)
  NgrokAPI::Models::EventDestination.new(client: self, result: result)
end

#list(before_id: nil, limit: nil, url: nil) ⇒ NgrokAPI::Models::Listable

List all Event Destinations on this account.

https://ngrok.com/docs/api#api-event-destinations-list

Parameters:

  • before_id (string) (defaults to: nil)
  • limit (string) (defaults to: nil)
  • url (string) (defaults to: nil)

    optional and mutually exclusive from before_id and limit

Returns:



123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
# File 'lib/ngrokapi/services/event_destinations_client.rb', line 123

def list(before_id: nil, limit: nil,
         url: nil)
  result = @client.list(
    before_id: before_id,
    limit: limit,
    url: url,
    path: PATH
  )

  NgrokAPI::Models::Listable.new(
    client: self,
    result: result,
    list_property: LIST_PROPERTY,
    klass: NgrokAPI::Models::EventDestination
  )
end

#list!(before_id: nil, limit: nil, url: nil) ⇒ NgrokAPI::Models::Listable

List all Event Destinations on this account. Throws an exception if API error.

https://ngrok.com/docs/api#api-event-destinations-list

Parameters:

  • before_id (string) (defaults to: nil)
  • limit (string) (defaults to: nil)
  • url (string) (defaults to: nil)

    optional and mutually exclusive from before_id and limit

Returns:



150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
# File 'lib/ngrokapi/services/event_destinations_client.rb', line 150

def list!(before_id: nil, limit: nil,
          url: nil)
  result = @client.list(
    before_id: before_id,
    limit: limit,
    danger: true,
    url: url,
    path: PATH
  )

  NgrokAPI::Models::Listable.new(
    client: self,
    result: result,
    list_property: LIST_PROPERTY,
    klass: NgrokAPI::Models::EventDestination,
    danger: true
  )
end

#update(id: "", metadata: nil, description: nil, format: nil, target: nil, verify_with_test_event: nil) ⇒ NgrokAPI::Models::EventDestination

Update attributes of an Event Destination.

https://ngrok.com/docs/api#api-event-destinations-update

Parameters:

  • id (string) (defaults to: "")

    Unique identifier for this Event Destination.

  • metadata (string) (defaults to: nil)

    Arbitrary user-defined machine-readable data of this Event Destination. Optional, max 4096 bytes.

  • description (string) (defaults to: nil)

    Human-readable description of the Event Destination. Optional, max 255 bytes.

  • format (string) (defaults to: nil)

    The output format you would like to serialize events into when sending to their target. Currently the only accepted value is JSON.

  • target (EventTarget) (defaults to: nil)

    An object that encapsulates where and how to send your events. An event destination must contain exactly one of the following objects, leaving the rest null: kinesis, firehose, cloudwatch_logs, or s3.

Returns:



180
181
182
183
184
185
186
187
188
189
190
191
192
# File 'lib/ngrokapi/services/event_destinations_client.rb', line 180

def update(id: "", metadata: nil, description: nil, format: nil, target: nil, verify_with_test_event: nil)
  path = '/event_destinations/%{id}'
  replacements = {
    id: id,
  }
  data = {}
  data[:metadata] =  if 
  data[:description] = description if description
  data[:format] = format if format
  data[:target] = target if target
  result = @client.patch(path % replacements, data: data)
  NgrokAPI::Models::EventDestination.new(client: self, result: result)
end

#update!(id: "", metadata: nil, description: nil, format: nil, target: nil, verify_with_test_event: nil) ⇒ NgrokAPI::Models::EventDestination

Update attributes of an Event Destination. Throws an exception if API error.

https://ngrok.com/docs/api#api-event-destinations-update

Parameters:

  • id (string) (defaults to: "")

    Unique identifier for this Event Destination.

  • metadata (string) (defaults to: nil)

    Arbitrary user-defined machine-readable data of this Event Destination. Optional, max 4096 bytes.

  • description (string) (defaults to: nil)

    Human-readable description of the Event Destination. Optional, max 255 bytes.

  • format (string) (defaults to: nil)

    The output format you would like to serialize events into when sending to their target. Currently the only accepted value is JSON.

  • target (EventTarget) (defaults to: nil)

    An object that encapsulates where and how to send your events. An event destination must contain exactly one of the following objects, leaving the rest null: kinesis, firehose, cloudwatch_logs, or s3.

Returns:



206
207
208
209
210
211
212
213
214
215
216
217
218
# File 'lib/ngrokapi/services/event_destinations_client.rb', line 206

def update!(id: "", metadata: nil, description: nil, format: nil, target: nil, verify_with_test_event: nil)
  path = '/event_destinations/%{id}'
  replacements = {
    id: id,
  }
  data = {}
  data[:metadata] =  if 
  data[:description] = description if description
  data[:format] = format if format
  data[:target] = target if target
  result = @client.patch(path % replacements, data: data, danger: true)
  NgrokAPI::Models::EventDestination.new(client: self, result: result)
end