Class: NgrokAPI::Services::EventDestinationsClient
- Inherits:
-
Object
- Object
- NgrokAPI::Services::EventDestinationsClient
- Defined in:
- lib/ngrokapi/services/event_destinations_client.rb
Overview
Constant Summary collapse
- PATH =
The API path for the requests
'/event_destinations'- LIST_PROPERTY =
The List Property from the resulting API for list calls
'event_destinations'
Instance Attribute Summary collapse
-
#client ⇒ Object
readonly
Returns the value of attribute client.
Instance Method Summary collapse
-
#create(metadata: "", description: "", format: "", target: nil, verify_with_test_event: nil) ⇒ NgrokAPI::Models::EventDestination
Create a new Event Destination.
-
#delete(id: "") ⇒ NgrokAPI::Models::Empty
Delete an Event Destination.
-
#delete!(id: "") ⇒ NgrokAPI::Models::Empty
Delete an Event Destination.
-
#get(id: "") ⇒ NgrokAPI::Models::EventDestination
Get detailed information about an Event Destination by ID.
-
#get!(id: "") ⇒ NgrokAPI::Models::EventDestination
Get detailed information about an Event Destination by ID.
-
#initialize(client:) ⇒ EventDestinationsClient
constructor
A new instance of EventDestinationsClient.
-
#list(before_id: nil, limit: nil, url: nil) ⇒ NgrokAPI::Models::Listable
List all Event Destinations on this account.
-
#update(id: "", metadata: nil, description: nil, format: nil, target: nil, verify_with_test_event: nil) ⇒ NgrokAPI::Models::EventDestination
Update attributes of an Event Destination.
-
#update!(id: "", metadata: nil, description: nil, format: nil, target: nil, verify_with_test_event: nil) ⇒ NgrokAPI::Models::EventDestination
Update attributes of an Event Destination.
Constructor Details
#initialize(client:) ⇒ EventDestinationsClient
Returns a new instance of EventDestinationsClient.
15 16 17 |
# File 'lib/ngrokapi/services/event_destinations_client.rb', line 15 def initialize(client:) @client = client end |
Instance Attribute Details
#client ⇒ Object (readonly)
Returns the value of attribute client.
13 14 15 |
# File 'lib/ngrokapi/services/event_destinations_client.rb', line 13 def client @client end |
Instance Method Details
#create(metadata: "", description: "", format: "", target: nil, verify_with_test_event: nil) ⇒ NgrokAPI::Models::EventDestination
Create a new Event Destination. It will not apply to anything until it is associated with an Event Stream, and that Event Stream is associated with an Endpoint Config.
31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 |
# File 'lib/ngrokapi/services/event_destinations_client.rb', line 31 def create( metadata: "", description: "", format: "", target: nil, verify_with_test_event: nil ) path = '/event_destinations' replacements = { } data = {} data[:metadata] = if data[:description] = description if description data[:format] = format if format data[:target] = target if target result = @client.post(path % replacements, data: data) NgrokAPI::Models::EventDestination.new(client: self, result: result) end |
#delete(id: "") ⇒ NgrokAPI::Models::Empty
Delete an Event Destination. If the Event Destination is still referenced by an Event Stream, this will throw an error until that Event Stream has removed that reference.
59 60 61 62 63 64 65 66 67 |
# File 'lib/ngrokapi/services/event_destinations_client.rb', line 59 def delete( id: "" ) path = '/event_destinations/%{id}' replacements = { id: id, } @client.delete(path % replacements) end |
#delete!(id: "") ⇒ NgrokAPI::Models::Empty
Delete an Event Destination. If the Event Destination is still referenced by an Event Stream, this will throw an error until that Event Stream has removed that reference. Throws an exception if API error.
79 80 81 82 83 84 85 86 87 |
# File 'lib/ngrokapi/services/event_destinations_client.rb', line 79 def delete!( id: "" ) path = '/event_destinations/%{id}' replacements = { id: id, } @client.delete(path % replacements, danger: true) end |
#get(id: "") ⇒ NgrokAPI::Models::EventDestination
Get detailed information about an Event Destination by ID.
96 97 98 99 100 101 102 103 104 105 106 |
# File 'lib/ngrokapi/services/event_destinations_client.rb', line 96 def get( id: "" ) path = '/event_destinations/%{id}' replacements = { id: id, } data = {} result = @client.get(path % replacements, data: data) NgrokAPI::Models::EventDestination.new(client: self, result: result) end |
#get!(id: "") ⇒ NgrokAPI::Models::EventDestination
Get detailed information about an Event Destination by ID. Throws an exception if API error.
116 117 118 119 120 121 122 123 124 125 126 |
# File 'lib/ngrokapi/services/event_destinations_client.rb', line 116 def get!( id: "" ) path = '/event_destinations/%{id}' replacements = { id: id, } data = {} result = @client.get(path % replacements, data: data, danger: true) NgrokAPI::Models::EventDestination.new(client: self, result: result) end |
#list(before_id: nil, limit: nil, url: nil) ⇒ NgrokAPI::Models::Listable
List all Event Destinations on this account.
137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 |
# File 'lib/ngrokapi/services/event_destinations_client.rb', line 137 def list( before_id: nil, limit: nil, url: nil ) result = @client.list( before_id: before_id, limit: limit, url: url, path: PATH ) NgrokAPI::Models::Listable.new( client: self, result: result, list_property: LIST_PROPERTY, klass: NgrokAPI::Models::EventDestination ) end |
#update(id: "", metadata: nil, description: nil, format: nil, target: nil, verify_with_test_event: nil) ⇒ NgrokAPI::Models::EventDestination
Update attributes of an Event Destination.
167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 |
# File 'lib/ngrokapi/services/event_destinations_client.rb', line 167 def update( id: "", metadata: nil, description: nil, format: nil, target: nil, verify_with_test_event: nil ) path = '/event_destinations/%{id}' replacements = { id: id, } data = {} data[:metadata] = if data[:description] = description if description data[:format] = format if format data[:target] = target if target result = @client.patch(path % replacements, data: data) NgrokAPI::Models::EventDestination.new(client: self, result: result) end |
#update!(id: "", metadata: nil, description: nil, format: nil, target: nil, verify_with_test_event: nil) ⇒ NgrokAPI::Models::EventDestination
Update attributes of an Event Destination. Throws an exception if API error.
200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 |
# File 'lib/ngrokapi/services/event_destinations_client.rb', line 200 def update!( id: "", metadata: nil, description: nil, format: nil, target: nil, verify_with_test_event: nil ) path = '/event_destinations/%{id}' replacements = { id: id, } data = {} data[:metadata] = if data[:description] = description if description data[:format] = format if format data[:target] = target if target result = @client.patch(path % replacements, data: data, danger: true) NgrokAPI::Models::EventDestination.new(client: self, result: result) end |