Class: NgrokAPI::Services::FailoverBackendsClient
- Inherits:
-
Object
- Object
- NgrokAPI::Services::FailoverBackendsClient
- Defined in:
- lib/ngrokapi/services/failover_backends_client.rb
Overview
A Failover backend defines failover behavior within a list of referenced backends. Traffic is sent to the first backend in the list. If that backend is offline or no connection can be established, ngrok attempts to connect to the next backend in the list until one is successful.
Constant Summary collapse
- PATH =
The API path for the requests
'/backends/failover'- LIST_PROPERTY =
The List Property from the resulting API for list calls
'backends'
Instance Attribute Summary collapse
-
#client ⇒ Object
readonly
Returns the value of attribute client.
Instance Method Summary collapse
-
#create(description: "", metadata: "", backends: []) ⇒ NgrokAPI::Models::FailoverBackend
Create a new Failover backend.
-
#delete(id: "") ⇒ NgrokAPI::Models::Empty
Delete a Failover backend by ID.
-
#delete!(id: "") ⇒ NgrokAPI::Models::Empty
Delete a Failover backend by ID.
-
#get(id: "") ⇒ NgrokAPI::Models::FailoverBackend
Get detailed information about a Failover backend by ID.
-
#get!(id: "") ⇒ NgrokAPI::Models::FailoverBackend
Get detailed information about a Failover backend by ID Throws an exception if API error.
-
#initialize(client:) ⇒ FailoverBackendsClient
constructor
A new instance of FailoverBackendsClient.
-
#list(before_id: nil, limit: nil, url: nil) ⇒ NgrokAPI::Models::Listable
List all Failover backends on this account.
-
#list!(before_id: nil, limit: nil, url: nil) ⇒ NgrokAPI::Models::Listable
List all Failover backends on this account Throws an exception if API error.
-
#update(id: "", description: nil, metadata: nil, backends: []) ⇒ NgrokAPI::Models::FailoverBackend
Update Failover backend by ID.
-
#update!(id: "", description: nil, metadata: nil, backends: []) ⇒ NgrokAPI::Models::FailoverBackend
Update Failover backend by ID Throws an exception if API error.
Constructor Details
#initialize(client:) ⇒ FailoverBackendsClient
Returns a new instance of FailoverBackendsClient.
20 21 22 |
# File 'lib/ngrokapi/services/failover_backends_client.rb', line 20 def initialize(client:) @client = client end |
Instance Attribute Details
#client ⇒ Object (readonly)
Returns the value of attribute client.
18 19 20 |
# File 'lib/ngrokapi/services/failover_backends_client.rb', line 18 def client @client end |
Instance Method Details
#create(description: "", metadata: "", backends: []) ⇒ NgrokAPI::Models::FailoverBackend
Create a new Failover backend
33 34 35 36 37 38 39 40 41 42 43 |
# File 'lib/ngrokapi/services/failover_backends_client.rb', line 33 def create(description: "", metadata: "", backends: []) path = '/backends/failover' replacements = { } data = {} data[:description] = description if description data[:metadata] = if data[:backends] = backends if backends result = @client.post(path % replacements, data: data) NgrokAPI::Models::FailoverBackend.new(client: self, result: result) end |
#delete(id: "") ⇒ NgrokAPI::Models::Empty
Delete a Failover backend by ID. TODO what if used?
52 53 54 55 56 57 58 |
# File 'lib/ngrokapi/services/failover_backends_client.rb', line 52 def delete(id: "") path = '/backends/failover/%{id}' replacements = { id: id, } @client.delete(path % replacements) end |
#delete!(id: "") ⇒ NgrokAPI::Models::Empty
Delete a Failover backend by ID. TODO what if used? Throws an exception if API error.
68 69 70 71 72 73 74 |
# File 'lib/ngrokapi/services/failover_backends_client.rb', line 68 def delete!(id: "") path = '/backends/failover/%{id}' replacements = { id: id, } @client.delete(path % replacements, danger: true) end |
#get(id: "") ⇒ NgrokAPI::Models::FailoverBackend
Get detailed information about a Failover backend by ID
83 84 85 86 87 88 89 90 91 |
# File 'lib/ngrokapi/services/failover_backends_client.rb', line 83 def get(id: "") path = '/backends/failover/%{id}' replacements = { id: id, } data = {} result = @client.get(path % replacements, data: data) NgrokAPI::Models::FailoverBackend.new(client: self, result: result) end |
#get!(id: "") ⇒ NgrokAPI::Models::FailoverBackend
Get detailed information about a Failover backend by ID Throws an exception if API error.
101 102 103 104 105 106 107 108 109 |
# File 'lib/ngrokapi/services/failover_backends_client.rb', line 101 def get!(id: "") path = '/backends/failover/%{id}' replacements = { id: id, } data = {} result = @client.get(path % replacements, data: data, danger: true) NgrokAPI::Models::FailoverBackend.new(client: self, result: result) end |
#list(before_id: nil, limit: nil, url: nil) ⇒ NgrokAPI::Models::Listable
List all Failover backends on this account
120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 |
# File 'lib/ngrokapi/services/failover_backends_client.rb', line 120 def list(before_id: nil, limit: nil, url: nil) result = @client.list( before_id: before_id, limit: limit, url: url, path: PATH ) NgrokAPI::Models::Listable.new( client: self, result: result, list_property: LIST_PROPERTY, klass: NgrokAPI::Models::FailoverBackend ) end |
#list!(before_id: nil, limit: nil, url: nil) ⇒ NgrokAPI::Models::Listable
List all Failover backends on this account Throws an exception if API error.
147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 |
# File 'lib/ngrokapi/services/failover_backends_client.rb', line 147 def list!(before_id: nil, limit: nil, url: nil) result = @client.list( before_id: before_id, limit: limit, danger: true, url: url, path: PATH ) NgrokAPI::Models::Listable.new( client: self, result: result, list_property: LIST_PROPERTY, klass: NgrokAPI::Models::FailoverBackend, danger: true ) end |
#update(id: "", description: nil, metadata: nil, backends: []) ⇒ NgrokAPI::Models::FailoverBackend
Update Failover backend by ID
176 177 178 179 180 181 182 183 184 185 186 187 |
# File 'lib/ngrokapi/services/failover_backends_client.rb', line 176 def update(id: "", description: nil, metadata: nil, backends: []) path = '/backends/failover/%{id}' replacements = { id: id, } data = {} data[:description] = description if description data[:metadata] = if data[:backends] = backends if backends result = @client.patch(path % replacements, data: data) NgrokAPI::Models::FailoverBackend.new(client: self, result: result) end |
#update!(id: "", description: nil, metadata: nil, backends: []) ⇒ NgrokAPI::Models::FailoverBackend
Update Failover backend by ID Throws an exception if API error.
200 201 202 203 204 205 206 207 208 209 210 211 |
# File 'lib/ngrokapi/services/failover_backends_client.rb', line 200 def update!(id: "", description: nil, metadata: nil, backends: []) path = '/backends/failover/%{id}' replacements = { id: id, } data = {} data[:description] = description if description data[:metadata] = if data[:backends] = backends if backends result = @client.patch(path % replacements, data: data, danger: true) NgrokAPI::Models::FailoverBackend.new(client: self, result: result) end |