Class: NgrokAPI::Services::IPPolicyRulesClient
- Inherits:
-
Object
- Object
- NgrokAPI::Services::IPPolicyRulesClient
- Defined in:
- lib/ngrokapi/services/ip_policy_rules_client.rb
Overview
IP Policy Rules are the IPv4 or IPv6 CIDRs entries that make up an IP Policy.
Constant Summary collapse
- PATH =
The API path for the requests
'/ip_policy_rules'- LIST_PROPERTY =
The List Property from the resulting API for list calls
'ip_policy_rules'
Instance Attribute Summary collapse
-
#client ⇒ Object
readonly
Returns the value of attribute client.
Instance Method Summary collapse
-
#create(description: "", metadata: "", cidr:, ip_policy_id:) ⇒ NgrokAPI::Models::IPPolicyRule
Create a new IP policy rule attached to an IP Policy.
-
#delete(id: "") ⇒ NgrokAPI::Models::Empty
Delete an IP policy rule.
-
#delete!(id: "") ⇒ NgrokAPI::Models::Empty
Delete an IP policy rule.
-
#get(id: "") ⇒ NgrokAPI::Models::IPPolicyRule
Get detailed information about an IP policy rule by ID.
-
#get!(id: "") ⇒ NgrokAPI::Models::IPPolicyRule
Get detailed information about an IP policy rule by ID.
-
#initialize(client:) ⇒ IPPolicyRulesClient
constructor
A new instance of IPPolicyRulesClient.
-
#list(before_id: nil, limit: nil, url: nil) ⇒ NgrokAPI::Models::Listable
List all IP policy rules on this account.
-
#list!(before_id: nil, limit: nil, url: nil) ⇒ NgrokAPI::Models::Listable
List all IP policy rules on this account Throws an exception if API error.
-
#update(id: "", description: nil, metadata: nil, cidr: nil) ⇒ NgrokAPI::Models::IPPolicyRule
Update attributes of an IP policy rule by ID.
-
#update!(id: "", description: nil, metadata: nil, cidr: nil) ⇒ NgrokAPI::Models::IPPolicyRule
Update attributes of an IP policy rule by ID Throws an exception if API error.
Constructor Details
#initialize(client:) ⇒ IPPolicyRulesClient
Returns a new instance of IPPolicyRulesClient.
18 19 20 |
# File 'lib/ngrokapi/services/ip_policy_rules_client.rb', line 18 def initialize(client:) @client = client end |
Instance Attribute Details
#client ⇒ Object (readonly)
Returns the value of attribute client.
16 17 18 |
# File 'lib/ngrokapi/services/ip_policy_rules_client.rb', line 16 def client @client end |
Instance Method Details
#create(description: "", metadata: "", cidr:, ip_policy_id:) ⇒ NgrokAPI::Models::IPPolicyRule
Create a new IP policy rule attached to an IP Policy.
32 33 34 35 36 37 38 39 40 41 42 43 |
# File 'lib/ngrokapi/services/ip_policy_rules_client.rb', line 32 def create(description: "", metadata: "", cidr:, ip_policy_id:) path = '/ip_policy_rules' replacements = { } data = {} data[:description] = description if description data[:metadata] = if data[:cidr] = cidr if cidr data[:ip_policy_id] = ip_policy_id if ip_policy_id result = @client.post(path % replacements, data: data) NgrokAPI::Models::IPPolicyRule.new(client: self, result: result) end |
#delete(id: "") ⇒ NgrokAPI::Models::Empty
Delete an IP policy rule.
52 53 54 55 56 57 58 |
# File 'lib/ngrokapi/services/ip_policy_rules_client.rb', line 52 def delete(id: "") path = '/ip_policy_rules/%{id}' replacements = { id: id, } @client.delete(path % replacements) end |
#delete!(id: "") ⇒ NgrokAPI::Models::Empty
Delete an IP policy rule. Throws an exception if API error.
68 69 70 71 72 73 74 |
# File 'lib/ngrokapi/services/ip_policy_rules_client.rb', line 68 def delete!(id: "") path = '/ip_policy_rules/%{id}' replacements = { id: id, } @client.delete(path % replacements, danger: true) end |
#get(id: "") ⇒ NgrokAPI::Models::IPPolicyRule
Get detailed information about an IP policy rule by ID.
83 84 85 86 87 88 89 90 91 |
# File 'lib/ngrokapi/services/ip_policy_rules_client.rb', line 83 def get(id: "") path = '/ip_policy_rules/%{id}' replacements = { id: id, } data = {} result = @client.get(path % replacements, data: data) NgrokAPI::Models::IPPolicyRule.new(client: self, result: result) end |
#get!(id: "") ⇒ NgrokAPI::Models::IPPolicyRule
Get detailed information about an IP policy rule by ID. Throws an exception if API error.
101 102 103 104 105 106 107 108 109 |
# File 'lib/ngrokapi/services/ip_policy_rules_client.rb', line 101 def get!(id: "") path = '/ip_policy_rules/%{id}' replacements = { id: id, } data = {} result = @client.get(path % replacements, data: data, danger: true) NgrokAPI::Models::IPPolicyRule.new(client: self, result: result) end |
#list(before_id: nil, limit: nil, url: nil) ⇒ NgrokAPI::Models::Listable
List all IP policy rules on this account
120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 |
# File 'lib/ngrokapi/services/ip_policy_rules_client.rb', line 120 def list(before_id: nil, limit: nil, url: nil) result = @client.list( before_id: before_id, limit: limit, url: url, path: PATH ) NgrokAPI::Models::Listable.new( client: self, result: result, list_property: LIST_PROPERTY, klass: NgrokAPI::Models::IPPolicyRule ) end |
#list!(before_id: nil, limit: nil, url: nil) ⇒ NgrokAPI::Models::Listable
List all IP policy rules on this account Throws an exception if API error.
147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 |
# File 'lib/ngrokapi/services/ip_policy_rules_client.rb', line 147 def list!(before_id: nil, limit: nil, url: nil) result = @client.list( before_id: before_id, limit: limit, danger: true, url: url, path: PATH ) NgrokAPI::Models::Listable.new( client: self, result: result, list_property: LIST_PROPERTY, klass: NgrokAPI::Models::IPPolicyRule, danger: true ) end |
#update(id: "", description: nil, metadata: nil, cidr: nil) ⇒ NgrokAPI::Models::IPPolicyRule
Update attributes of an IP policy rule by ID
176 177 178 179 180 181 182 183 184 185 186 187 |
# File 'lib/ngrokapi/services/ip_policy_rules_client.rb', line 176 def update(id: "", description: nil, metadata: nil, cidr: nil) path = '/ip_policy_rules/%{id}' replacements = { id: id, } data = {} data[:description] = description if description data[:metadata] = if data[:cidr] = cidr if cidr result = @client.patch(path % replacements, data: data) NgrokAPI::Models::IPPolicyRule.new(client: self, result: result) end |
#update!(id: "", description: nil, metadata: nil, cidr: nil) ⇒ NgrokAPI::Models::IPPolicyRule
Update attributes of an IP policy rule by ID Throws an exception if API error.
200 201 202 203 204 205 206 207 208 209 210 211 |
# File 'lib/ngrokapi/services/ip_policy_rules_client.rb', line 200 def update!(id: "", description: nil, metadata: nil, cidr: nil) path = '/ip_policy_rules/%{id}' replacements = { id: id, } data = {} data[:description] = description if description data[:metadata] = if data[:cidr] = cidr if cidr result = @client.patch(path % replacements, data: data, danger: true) NgrokAPI::Models::IPPolicyRule.new(client: self, result: result) end |