Class: NgrokAPI::Services::IPRestrictionsClient
- Inherits:
-
Object
- Object
- NgrokAPI::Services::IPRestrictionsClient
- Defined in:
- lib/ngrokapi/services/ip_restrictions_client.rb
Overview
An IP restriction is a restriction placed on the CIDRs that are allowed to
initate traffic to a specific aspect of your ngrok account. An IP
restriction has a type which defines the ingress it applies to. IP
restrictions can be used to enforce the source IPs that can make API
requests, log in to the dashboard, start ngrok agents, and connect to your
public-facing endpoints.
Constant Summary collapse
- PATH =
The API path for the requests
'/ip_restrictions'- LIST_PROPERTY =
The List Property from the resulting API for list calls
'ip_restrictions'
Instance Attribute Summary collapse
-
#client ⇒ Object
readonly
Returns the value of attribute client.
Instance Method Summary collapse
-
#create(description: "", metadata: "", enforced: False, type:, ip_policy_ids:) ⇒ NgrokAPI::Models::IPRestriction
Create a new IP restriction.
-
#delete(id: "") ⇒ NgrokAPI::Models::Empty
Delete an IP restriction.
-
#delete!(id: "") ⇒ NgrokAPI::Models::Empty
Delete an IP restriction Throws an exception if API error.
-
#get(id: "") ⇒ NgrokAPI::Models::IPRestriction
Get detailed information about an IP restriction.
-
#get!(id: "") ⇒ NgrokAPI::Models::IPRestriction
Get detailed information about an IP restriction Throws an exception if API error.
-
#initialize(client:) ⇒ IPRestrictionsClient
constructor
A new instance of IPRestrictionsClient.
-
#list(before_id: nil, limit: nil, url: nil) ⇒ NgrokAPI::Models::Listable
List all IP restrictions on this account.
-
#update(id: "", description: nil, metadata: nil, enforced: nil, ip_policy_ids: []) ⇒ NgrokAPI::Models::IPRestriction
Update attributes of an IP restriction by ID.
-
#update!(id: "", description: nil, metadata: nil, enforced: nil, ip_policy_ids: []) ⇒ NgrokAPI::Models::IPRestriction
Update attributes of an IP restriction by ID Throws an exception if API error.
Constructor Details
#initialize(client:) ⇒ IPRestrictionsClient
Returns a new instance of IPRestrictionsClient.
22 23 24 |
# File 'lib/ngrokapi/services/ip_restrictions_client.rb', line 22 def initialize(client:) @client = client end |
Instance Attribute Details
#client ⇒ Object (readonly)
Returns the value of attribute client.
20 21 22 |
# File 'lib/ngrokapi/services/ip_restrictions_client.rb', line 20 def client @client end |
Instance Method Details
#create(description: "", metadata: "", enforced: False, type:, ip_policy_ids:) ⇒ NgrokAPI::Models::IPRestriction
Create a new IP restriction
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 |
# File 'lib/ngrokapi/services/ip_restrictions_client.rb', line 37 def create( description: "", metadata: "", enforced: False, type:, ip_policy_ids: ) path = '/ip_restrictions' replacements = { } data = {} data[:description] = description if description data[:metadata] = if data[:enforced] = enforced if enforced data[:type] = type if type data[:ip_policy_ids] = ip_policy_ids if ip_policy_ids result = @client.post(path % replacements, data: data) NgrokAPI::Models::IPRestriction.new(client: self, result: result) end |
#delete(id: "") ⇒ NgrokAPI::Models::Empty
Delete an IP restriction
64 65 66 67 68 69 70 71 72 |
# File 'lib/ngrokapi/services/ip_restrictions_client.rb', line 64 def delete( id: "" ) path = '/ip_restrictions/%{id}' replacements = { id: id, } @client.delete(path % replacements) end |
#delete!(id: "") ⇒ NgrokAPI::Models::Empty
Delete an IP restriction Throws an exception if API error.
82 83 84 85 86 87 88 89 90 |
# File 'lib/ngrokapi/services/ip_restrictions_client.rb', line 82 def delete!( id: "" ) path = '/ip_restrictions/%{id}' replacements = { id: id, } @client.delete(path % replacements, danger: true) end |
#get(id: "") ⇒ NgrokAPI::Models::IPRestriction
Get detailed information about an IP restriction
99 100 101 102 103 104 105 106 107 108 109 |
# File 'lib/ngrokapi/services/ip_restrictions_client.rb', line 99 def get( id: "" ) path = '/ip_restrictions/%{id}' replacements = { id: id, } data = {} result = @client.get(path % replacements, data: data) NgrokAPI::Models::IPRestriction.new(client: self, result: result) end |
#get!(id: "") ⇒ NgrokAPI::Models::IPRestriction
Get detailed information about an IP restriction Throws an exception if API error.
119 120 121 122 123 124 125 126 127 128 129 |
# File 'lib/ngrokapi/services/ip_restrictions_client.rb', line 119 def get!( id: "" ) path = '/ip_restrictions/%{id}' replacements = { id: id, } data = {} result = @client.get(path % replacements, data: data, danger: true) NgrokAPI::Models::IPRestriction.new(client: self, result: result) end |
#list(before_id: nil, limit: nil, url: nil) ⇒ NgrokAPI::Models::Listable
List all IP restrictions on this account
140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 |
# File 'lib/ngrokapi/services/ip_restrictions_client.rb', line 140 def list( before_id: nil, limit: nil, url: nil ) result = @client.list( before_id: before_id, limit: limit, url: url, path: PATH ) NgrokAPI::Models::Listable.new( client: self, result: result, list_property: LIST_PROPERTY, klass: NgrokAPI::Models::IPRestriction ) end |
#update(id: "", description: nil, metadata: nil, enforced: nil, ip_policy_ids: []) ⇒ NgrokAPI::Models::IPRestriction
Update attributes of an IP restriction by ID
170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 |
# File 'lib/ngrokapi/services/ip_restrictions_client.rb', line 170 def update( id: "", description: nil, metadata: nil, enforced: nil, ip_policy_ids: [] ) path = '/ip_restrictions/%{id}' replacements = { id: id, } data = {} data[:description] = description if description data[:metadata] = if data[:enforced] = enforced if enforced data[:ip_policy_ids] = ip_policy_ids if ip_policy_ids result = @client.patch(path % replacements, data: data) NgrokAPI::Models::IPRestriction.new(client: self, result: result) end |
#update!(id: "", description: nil, metadata: nil, enforced: nil, ip_policy_ids: []) ⇒ NgrokAPI::Models::IPRestriction
Update attributes of an IP restriction by ID Throws an exception if API error.
202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 |
# File 'lib/ngrokapi/services/ip_restrictions_client.rb', line 202 def update!( id: "", description: nil, metadata: nil, enforced: nil, ip_policy_ids: [] ) path = '/ip_restrictions/%{id}' replacements = { id: id, } data = {} data[:description] = description if description data[:metadata] = if data[:enforced] = enforced if enforced data[:ip_policy_ids] = ip_policy_ids if ip_policy_ids result = @client.patch(path % replacements, data: data, danger: true) NgrokAPI::Models::IPRestriction.new(client: self, result: result) end |