Class: NgrokAPI::Services::SSHCertificateAuthoritiesClient

Inherits:
Object
  • Object
show all
Defined in:
lib/ngrokapi/services/ssh_certificate_authorities_client.rb

Overview

An SSH Certificate Authority is a pair of an SSH Certificate and its private

key that can be used to sign other SSH host and user certificates.

ngrok.com/docs/api#api-ssh-certificate-authorities

Constant Summary collapse

PATH =

The API path for the requests

'/ssh_certificate_authorities'
LIST_PROPERTY =

The List Property from the resulting API for list calls

'ssh_certificate_authorities'

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(client:) ⇒ SSHCertificateAuthoritiesClient

Returns a new instance of SSHCertificateAuthoritiesClient.



18
19
20
# File 'lib/ngrokapi/services/ssh_certificate_authorities_client.rb', line 18

def initialize(client:)
  @client = client
end

Instance Attribute Details

#clientObject (readonly)

Returns the value of attribute client.



16
17
18
# File 'lib/ngrokapi/services/ssh_certificate_authorities_client.rb', line 16

def client
  @client
end

Instance Method Details

#create(description: "", metadata: "", private_key_type: "", elliptic_curve: "", key_size: 0) ⇒ NgrokAPI::Models::SSHCertificateAuthority

Create a new SSH Certificate Authority

ngrok.com/docs/api#api-ssh-certificate-authorities-create

Parameters:

  • description (string) (defaults to: "")

    human-readable description of this SSH Certificate Authority. optional, max 255 bytes.

  • metadata (string) (defaults to: "")

    arbitrary user-defined machine-readable data of this SSH Certificate Authority. optional, max 4096 bytes.

  • private_key_type (string) (defaults to: "")

    the type of private key to generate. one of rsa, ecdsa, ed25519

  • elliptic_curve (string) (defaults to: "")

    the type of elliptic curve to use when creating an ECDSA key

  • key_size (int64) (defaults to: 0)

    the key size to use when creating an RSA key. one of 2048 or 4096

Returns:



33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
# File 'lib/ngrokapi/services/ssh_certificate_authorities_client.rb', line 33

def create(
  description: "",
  metadata: "",
  private_key_type: "",
  elliptic_curve: "",
  key_size: 0
)
  path = '/ssh_certificate_authorities'
  replacements = {
  }
  data = {}
  data[:description] = description if description
  data[:metadata] =  if 
  data[:private_key_type] = private_key_type if private_key_type
  data[:elliptic_curve] = elliptic_curve if elliptic_curve
  data[:key_size] = key_size if key_size
  result = @client.post(path % replacements, data: data)
  NgrokAPI::Models::SSHCertificateAuthority.new(client: self, result: result)
end

#delete(id: "") ⇒ NgrokAPI::Models::Empty

Delete an SSH Certificate Authority

ngrok.com/docs/api#api-ssh-certificate-authorities-delete

Parameters:

  • id (string) (defaults to: "")

    a resource identifier

Returns:

  • (NgrokAPI::Models::Empty)

    result from the API request



60
61
62
63
64
65
66
67
68
# File 'lib/ngrokapi/services/ssh_certificate_authorities_client.rb', line 60

def delete(
  id: ""
)
  path = '/ssh_certificate_authorities/%{id}'
  replacements = {
    id: id,
  }
  @client.delete(path % replacements)
end

#delete!(id: "") ⇒ NgrokAPI::Models::Empty

Delete an SSH Certificate Authority Throws an exception if API error.

ngrok.com/docs/api#api-ssh-certificate-authorities-delete

Parameters:

  • id (string) (defaults to: "")

    a resource identifier

Returns:

  • (NgrokAPI::Models::Empty)

    result from the API request



78
79
80
81
82
83
84
85
86
# File 'lib/ngrokapi/services/ssh_certificate_authorities_client.rb', line 78

def delete!(
  id: ""
)
  path = '/ssh_certificate_authorities/%{id}'
  replacements = {
    id: id,
  }
  @client.delete(path % replacements, danger: true)
end

#get(id: "") ⇒ NgrokAPI::Models::SSHCertificateAuthority

Get detailed information about an SSH Certficate Authority

ngrok.com/docs/api#api-ssh-certificate-authorities-get

Parameters:

  • id (string) (defaults to: "")

    a resource identifier

Returns:



95
96
97
98
99
100
101
102
103
104
105
# File 'lib/ngrokapi/services/ssh_certificate_authorities_client.rb', line 95

def get(
  id: ""
)
  path = '/ssh_certificate_authorities/%{id}'
  replacements = {
    id: id,
  }
  data = {}
  result = @client.get(path % replacements, data: data)
  NgrokAPI::Models::SSHCertificateAuthority.new(client: self, result: result)
end

#get!(id: "") ⇒ NgrokAPI::Models::SSHCertificateAuthority

Get detailed information about an SSH Certficate Authority Throws an exception if API error.

ngrok.com/docs/api#api-ssh-certificate-authorities-get

Parameters:

  • id (string) (defaults to: "")

    a resource identifier

Returns:



115
116
117
118
119
120
121
122
123
124
125
# File 'lib/ngrokapi/services/ssh_certificate_authorities_client.rb', line 115

def get!(
  id: ""
)
  path = '/ssh_certificate_authorities/%{id}'
  replacements = {
    id: id,
  }
  data = {}
  result = @client.get(path % replacements, data: data, danger: true)
  NgrokAPI::Models::SSHCertificateAuthority.new(client: self, result: result)
end

#list(before_id: nil, limit: nil, url: nil) ⇒ NgrokAPI::Models::Listable

List all SSH Certificate Authorities on this account

ngrok.com/docs/api#api-ssh-certificate-authorities-list

Parameters:

  • before_id (string) (defaults to: nil)
  • limit (string) (defaults to: nil)
  • url (string) (defaults to: nil)

    optional and mutually exclusive from before_id and limit

Returns:



136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
# File 'lib/ngrokapi/services/ssh_certificate_authorities_client.rb', line 136

def list(
  before_id: nil,
  limit: nil,
  url: nil
)
  result = @client.list(
    before_id: before_id,
    limit: limit,
    url: url,
    path: PATH
  )
  NgrokAPI::Models::Listable.new(
    client: self,
    result: result,
    list_property: LIST_PROPERTY,
    klass: NgrokAPI::Models::SSHCertificateAuthority
  )
end

#update(id: "", description: nil, metadata: nil) ⇒ NgrokAPI::Models::SSHCertificateAuthority

Update an SSH Certificate Authority

ngrok.com/docs/api#api-ssh-certificate-authorities-update

Parameters:

  • id (string) (defaults to: "")
  • description (string) (defaults to: nil)

    human-readable description of this SSH Certificate Authority. optional, max 255 bytes.

  • metadata (string) (defaults to: nil)

    arbitrary user-defined machine-readable data of this SSH Certificate Authority. optional, max 4096 bytes.

Returns:



164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
# File 'lib/ngrokapi/services/ssh_certificate_authorities_client.rb', line 164

def update(
  id: "",
  description: nil,
  metadata: nil
)
  path = '/ssh_certificate_authorities/%{id}'
  replacements = {
    id: id,
  }
  data = {}
  data[:description] = description if description
  data[:metadata] =  if 
  result = @client.patch(path % replacements, data: data)
  NgrokAPI::Models::SSHCertificateAuthority.new(client: self, result: result)
end

#update!(id: "", description: nil, metadata: nil) ⇒ NgrokAPI::Models::SSHCertificateAuthority

Update an SSH Certificate Authority Throws an exception if API error.

ngrok.com/docs/api#api-ssh-certificate-authorities-update

Parameters:

  • id (string) (defaults to: "")
  • description (string) (defaults to: nil)

    human-readable description of this SSH Certificate Authority. optional, max 255 bytes.

  • metadata (string) (defaults to: nil)

    arbitrary user-defined machine-readable data of this SSH Certificate Authority. optional, max 4096 bytes.

Returns:



190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
# File 'lib/ngrokapi/services/ssh_certificate_authorities_client.rb', line 190

def update!(
  id: "",
  description: nil,
  metadata: nil
)
  path = '/ssh_certificate_authorities/%{id}'
  replacements = {
    id: id,
  }
  data = {}
  data[:description] = description if description
  data[:metadata] =  if 
  result = @client.patch(path % replacements, data: data, danger: true)
  NgrokAPI::Models::SSHCertificateAuthority.new(client: self, result: result)
end