Class: NgrokAPI::Services::SSHCertificateAuthoritiesClient
- Inherits:
-
Object
- Object
- NgrokAPI::Services::SSHCertificateAuthoritiesClient
- Defined in:
- lib/ngrokapi/services/ssh_certificate_authorities_client.rb
Overview
An SSH Certificate Authority is a pair of an SSH Certificate and its private
key that can be used to sign other SSH host and user certificates.
Constant Summary collapse
- PATH =
The API path for the requests
'/ssh_certificate_authorities'- LIST_PROPERTY =
The List Property from the resulting API for list calls
'ssh_certificate_authorities'
Instance Attribute Summary collapse
-
#client ⇒ Object
readonly
Returns the value of attribute client.
Instance Method Summary collapse
-
#create(description: "", metadata: "", private_key_type: "", elliptic_curve: "", key_size: 0) ⇒ NgrokAPI::Models::SSHCertificateAuthority
Create a new SSH Certificate Authority.
-
#delete(id: "") ⇒ NgrokAPI::Models::Empty
Delete an SSH Certificate Authority.
-
#delete!(id: "") ⇒ NgrokAPI::Models::Empty
Delete an SSH Certificate Authority Throws an exception if API error.
-
#get(id: "") ⇒ NgrokAPI::Models::SSHCertificateAuthority
Get detailed information about an SSH Certficate Authority.
-
#get!(id: "") ⇒ NgrokAPI::Models::SSHCertificateAuthority
Get detailed information about an SSH Certficate Authority Throws an exception if API error.
-
#initialize(client:) ⇒ SSHCertificateAuthoritiesClient
constructor
A new instance of SSHCertificateAuthoritiesClient.
-
#list(before_id: nil, limit: nil, url: nil) ⇒ NgrokAPI::Models::Listable
List all SSH Certificate Authorities on this account.
-
#update(id: "", description: nil, metadata: nil) ⇒ NgrokAPI::Models::SSHCertificateAuthority
Update an SSH Certificate Authority.
-
#update!(id: "", description: nil, metadata: nil) ⇒ NgrokAPI::Models::SSHCertificateAuthority
Update an SSH Certificate Authority Throws an exception if API error.
Constructor Details
#initialize(client:) ⇒ SSHCertificateAuthoritiesClient
Returns a new instance of SSHCertificateAuthoritiesClient.
18 19 20 |
# File 'lib/ngrokapi/services/ssh_certificate_authorities_client.rb', line 18 def initialize(client:) @client = client end |
Instance Attribute Details
#client ⇒ Object (readonly)
Returns the value of attribute client.
16 17 18 |
# File 'lib/ngrokapi/services/ssh_certificate_authorities_client.rb', line 16 def client @client end |
Instance Method Details
#create(description: "", metadata: "", private_key_type: "", elliptic_curve: "", key_size: 0) ⇒ NgrokAPI::Models::SSHCertificateAuthority
Create a new SSH Certificate Authority
33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 |
# File 'lib/ngrokapi/services/ssh_certificate_authorities_client.rb', line 33 def create( description: "", metadata: "", private_key_type: "", elliptic_curve: "", key_size: 0 ) path = '/ssh_certificate_authorities' replacements = { } data = {} data[:description] = description if description data[:metadata] = if data[:private_key_type] = private_key_type if private_key_type data[:elliptic_curve] = elliptic_curve if elliptic_curve data[:key_size] = key_size if key_size result = @client.post(path % replacements, data: data) NgrokAPI::Models::SSHCertificateAuthority.new(client: self, result: result) end |
#delete(id: "") ⇒ NgrokAPI::Models::Empty
Delete an SSH Certificate Authority
60 61 62 63 64 65 66 67 68 |
# File 'lib/ngrokapi/services/ssh_certificate_authorities_client.rb', line 60 def delete( id: "" ) path = '/ssh_certificate_authorities/%{id}' replacements = { id: id, } @client.delete(path % replacements) end |
#delete!(id: "") ⇒ NgrokAPI::Models::Empty
Delete an SSH Certificate Authority Throws an exception if API error.
78 79 80 81 82 83 84 85 86 |
# File 'lib/ngrokapi/services/ssh_certificate_authorities_client.rb', line 78 def delete!( id: "" ) path = '/ssh_certificate_authorities/%{id}' replacements = { id: id, } @client.delete(path % replacements, danger: true) end |
#get(id: "") ⇒ NgrokAPI::Models::SSHCertificateAuthority
Get detailed information about an SSH Certficate Authority
95 96 97 98 99 100 101 102 103 104 105 |
# File 'lib/ngrokapi/services/ssh_certificate_authorities_client.rb', line 95 def get( id: "" ) path = '/ssh_certificate_authorities/%{id}' replacements = { id: id, } data = {} result = @client.get(path % replacements, data: data) NgrokAPI::Models::SSHCertificateAuthority.new(client: self, result: result) end |
#get!(id: "") ⇒ NgrokAPI::Models::SSHCertificateAuthority
Get detailed information about an SSH Certficate Authority Throws an exception if API error.
115 116 117 118 119 120 121 122 123 124 125 |
# File 'lib/ngrokapi/services/ssh_certificate_authorities_client.rb', line 115 def get!( id: "" ) path = '/ssh_certificate_authorities/%{id}' replacements = { id: id, } data = {} result = @client.get(path % replacements, data: data, danger: true) NgrokAPI::Models::SSHCertificateAuthority.new(client: self, result: result) end |
#list(before_id: nil, limit: nil, url: nil) ⇒ NgrokAPI::Models::Listable
List all SSH Certificate Authorities on this account
136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 |
# File 'lib/ngrokapi/services/ssh_certificate_authorities_client.rb', line 136 def list( before_id: nil, limit: nil, url: nil ) result = @client.list( before_id: before_id, limit: limit, url: url, path: PATH ) NgrokAPI::Models::Listable.new( client: self, result: result, list_property: LIST_PROPERTY, klass: NgrokAPI::Models::SSHCertificateAuthority ) end |
#update(id: "", description: nil, metadata: nil) ⇒ NgrokAPI::Models::SSHCertificateAuthority
Update an SSH Certificate Authority
164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 |
# File 'lib/ngrokapi/services/ssh_certificate_authorities_client.rb', line 164 def update( id: "", description: nil, metadata: nil ) path = '/ssh_certificate_authorities/%{id}' replacements = { id: id, } data = {} data[:description] = description if description data[:metadata] = if result = @client.patch(path % replacements, data: data) NgrokAPI::Models::SSHCertificateAuthority.new(client: self, result: result) end |
#update!(id: "", description: nil, metadata: nil) ⇒ NgrokAPI::Models::SSHCertificateAuthority
Update an SSH Certificate Authority Throws an exception if API error.
190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 |
# File 'lib/ngrokapi/services/ssh_certificate_authorities_client.rb', line 190 def update!( id: "", description: nil, metadata: nil ) path = '/ssh_certificate_authorities/%{id}' replacements = { id: id, } data = {} data[:description] = description if description data[:metadata] = if result = @client.patch(path % replacements, data: data, danger: true) NgrokAPI::Models::SSHCertificateAuthority.new(client: self, result: result) end |